/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 09522
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1988
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 09522-0001-statasetup.do)
 |
 **************************************************************************/

set mem 30m  /* Allocating 30 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "National Household Survey on Drug Abuse, 1988, Dataset 0001"

#delimit ;
label define CIGTRY    91 "NEVER USED CIGARETTES" 94 "DONT KNOW"
                       95 "BAD DATA" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CIG5PK    1 "Yes" 2 "No" 91 "NEVER USED CIGARETTES"
                       94 "DONT KNOW" 98 "BLANK" ;
label define CIGREC    1 "Within the past month(30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED CIGARETTES" 94 "DONT KNOW" 98 "BLANK" ;
label define AVCIG     1 "Less than one cigarette a day"
                       2 "One to five cigarettes a day"
                       3 "About 1/2 pack a day(6-15 cigarettes)"
                       4 "About a pack a day(16-25 cigarettes)"
                       5 "About 1 1/2 packs a day(26-35 cigarettes)"
                       6 "About 2 packs or more a day(over 35 cigarettes)"
                       91 "NEVER USED CIGARETTES" 94 "DONT KNOW" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define CIGTIME   91 "NEVER USED CIGARETTES" 94 "DONT KNOW"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CIGINT    1 "Years" 2 "Months" 3 "Weeks"
                       91 "NEVER USED CIGARETTES" 94 "DONT KNOW" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define CIGAGE    91 "NEVER USED CIGARETTES" 93 "NEVER SMOKED DAILY"
                       94 "DONT KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define CIGYRS    91 "NEVER USED CIGARETTES" 94 "DONT KNOW"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PACKS     1 "One to five cigarettes a day"
                       2 "About 1/2 pack a day(6-15 cigarettes)"
                       3 "About a pack a day(16-25 cigarettes)"
                       4 "About 1 1/2 packs a day(26-35 cigarettes)"
                       5 "About 2 packs or more a day(over 35 cigarettes)"
                       91 "NEVER USED CIGARETTES" 94 "DONT KNOW" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define SNUFREC   1 "Within the past month(30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       91 "NEVER USED SMOKELESS TOBACCO" 94 "DONT KNOW"
                       98 "BLANK" ;
label define SNUFFREQ  1 "Daily" 2 "Almost daily (3-6 days a week)"
                       3 "1 or 2 days a week"
                       4 "Several times a month(25-31 days a year)"
                       5 "1 or 2 times a month (12-24 days a year)"
                       6 "Every other month or so (6-11 days a year)"
                       7 "3-5 days this past year"
                       8 "1 or 2 days this past year"
                       91 "NEVER USED SMOKELESS TOBACCO"
                       93 "DID NOT USE SMOKELESS TOBACCO IN PAST 12 MONTHS"
                       95 "BAD DATA" 98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define ALCTRY    91 "NEVER USED ALCOHOL" 94 "DONT KNOW" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ALCREC    1 "Within the past month(30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED ALCOHOL" ;
label define ALCPREF   1 "Beer" 2 "Wine" 3 "Liquor" 4 "It varies"
                       91 "NEVER USED ALCOHOL" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ALCDAYS   91 "NEVER USED ALCOHOL" 94 "DONT KNOW" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define NODR30A   90 "90 or more drinks per day past 30 days"
                       91 "NEVER USED ALCOHOL" 94 "DONT KNOW" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define MODR30A   90 "90 or more drinks in one day in past 30 days"
                       91 "NEVER USED ALCOHOL" 94 "DONT KNOW" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define MODR30DY  91 "NEVER USED ALCOHOL" 94 "DONT KNOW" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DR5DAY    91 "NEVER USED ALCOHOL" 94 "DONT KNOW" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define ALCAGE    91 "NEVER USED ALCOHOL" 92 "ILLEGIBLE"
                       93 "NEVER USED ALCOHOL MONTHLY OR MORE OFTEN"
                       94 "DONT KNOW" 95 "BAD DATA" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCPAT    1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25-51 days)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTHS"
                       95 "BAD DATA" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DRUNKYR   1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25-51 days)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       9 "Never got very high or drunk in past 12 months"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTHS"
                       94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ALCSED    1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCTRAN   1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCSTM    1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCANAL   1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCMJ     1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCINH    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCCOC    1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCHAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCOPT    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCNONE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define NOSEDAT   1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" ;
label define BUTISOL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define BUTICAPS  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define AMYTAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define MEBARAL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define PLACIDYL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define DORIDEN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define NOLUDAR   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define NEMBUTAL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SECONAL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define TUINAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define DALMANE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define RESTORIL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define HALCION   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define AMOBARB   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define PHENOBAR  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define METHAQ    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define CHHYD     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define PENTOB    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SECOB     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDNEWA   122 "Sleep Aid" 123 "Unisom" 124 "Yellow jackets"
                       127 "Nytol" 134 "Diasetan" 136 "Dimetapp" 137 "7-14"
                       201 "Valium" 228 "Amitriptyline" 326 "White cross"
                       339 "Amphetamines (speed)" 401 "Darvon" 406 "Percodan"
                       407 "Demerol" 426 "Fiorinal" 427 "Darvocet"
                       435 "Tylenol" 991 "NEVER USED SEDATIVES"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SEDNEWB   123 "Unisom" 327 "Black Beauty, Black beauties"
                       991 "NEVER USED SEDATIVES" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define SEDNOSP   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDDKNAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDAGE    91 "NEVER USED SEDATIVES" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define SEDTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDREC    1 "Within the past month(30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDALC    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define SEDTR     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define SEDST     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define SEDAN     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define SEDMJ     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define SEDINH    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define SEDCOC    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define SEDHAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define SEDOPT    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define SEDNONE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define AS3READ   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself" 98 "BLANK" ;
label define NOTRANQ   1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" ;
label define VALIUM    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define LIBRIUM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define LIMBTROL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define MENRIUM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define SERAX     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRANXENE  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define ATIVAN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define CENTRAX   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define XANAX     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define PAXIPAM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define BUSPAR    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define MILTOWN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define EQUANIL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DEPROL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define VISTAR    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define ATARAX    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DURRAX    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DIAZEPAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define SKLY      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define MEPROB    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRNEWA    116 "Methaqualone (including Sopor, Quaalude)"
                       224 "Triavil" 225 "Desyrel" 227 "Thorazine"
                       418 "Methadone" 991 "NEVER USED TRANQUILIZERS"
                       998 "BLANK (NO ANSWER)" ;
label define TRNOSP    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRDKNAM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRANAGE   91 "NEVER USED TRANQUILIZERS" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define TRANTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRANREC   1 "Within the past month(30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRALC     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZER IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define TRSED     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZER IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define TRSTM     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZER IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define TRANAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZER IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define TRMJ      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZER IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define TRINH     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZER IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define TRCOC     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZER IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define TRHAL     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZER IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define TROPT     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZER IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define TRNONE    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZER IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define AS4READ   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself" 98 "BLANK" ;
label define NOSTIMS   1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" ;
label define DEXED     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DEXAMYL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define ESKAT     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define BENZ      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define BIPHET    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DESOXYN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define TENUATE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define TEPANIL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DIDREX    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define PLEGINE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define PRELUDIN  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define IONAMIN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define FASTIN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define PONDIMIN  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define VORANIL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define SANOREX   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define MAZANOR   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define RITALIN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define CYLERT    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DETAMP    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define METHI     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define METHAMP   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define OBLA      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STIMNEWA  326 "White cross" 327 "Black Beauty, Black beauties"
                       328 "Pink hearts" 330 "Blue Birds, Blue Jays"
                       331 "Whites"
                       332 "Ephedrine, Caffeine, No-Doz, Vivarin"
                       333 "357 Magnum, Magnum 44"
                       334 "Cross tops, Crossroads" 335 "Dexatrim"
                       336 "Diet pills" 337 "White Molly"
                       338 "Antiadipositum" 339 "Amphetamines (speed)"
                       340 "Tiamina 250" 343 "Nitroglycerine" 344 "Bennies"
                       345 "Black Molly" 346 "Ephedrine Sulfate"
                       348 "Crystal" 349 "Phentametrazine" 350 "Betin SS"
                       351 "Qat" 352 "Lemons" 991 "NEVER USED STIMULANTS"
                       995 "BAD DATA" 998 "BLANK (NO ANSWER)" ;
label define STIMNEWB  327 "Black Beauty, Black beauties"
                       332 "Ephedrine, Caffeine, No-Doz, Vivarin"
                       337 "White Molly" 341 "Pink roses"
                       347 "Phenylpropanolamine" 991 "NEVER USED STIMULANTS"
                       998 "BLANK (NO ANSWER)" ;
label define STIMNEWC  328 "Pink hearts" 329 "Speckled Eggs, Robins Eggs"
                       342 "Purple hearts" 991 "NEVER USED STIMULANTS"
                       998 "BLANK (NO ANSWER)" ;
label define STIMNEWD  329 "Speckled Eggs, Robins Eggs"
                       991 "NEVER USED STIMULANTS" 998 "BLANK (NO ANSWER)" ;
label define STIMNOSP  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STMDKNAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STIMAGE   91 "NEVER USED STIMULANTS" 94 "DONT KNOW"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define STIMTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED STIMULANTS" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define STIMREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STALC     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANT IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define STSED     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANT IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define STTRAN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANT IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define STANAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANT IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define STMJ      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANT IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define STINH     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANT IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define STCOC     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANT IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define STHAL     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANT IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define STOPT     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define STNONE    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANT IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define STNEEDLE  1 "Yes" 2 "No" 91 "NEVER USED STIMULANTS"
                       98 "BLANK (NO ANSWER)" ;
label define STNDLREC  1 "Within the past month(30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago" 91 "NEVER USED STIMULANTS"
                       93 "NEVER USED AMPHETAMINES WITH A NEEDLE"
                       98 "BLANK (NO ANSWER)" ;
label define AS5READ   1 "Wants interviewer to read questions"
                       2 "Wants to do it himself/herself" 98 "BLANK" ;
label define ANALNONE  1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" ;
label define DARVON    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define DOLENE    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define SK65A     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define WYGESIC   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define LEVODRO   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define PERCODAN  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define DEMEROL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define DILAUD    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TYLCOD    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define PHENCOD   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TALWIN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TALWINNX  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TALACEN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define PROPOXY   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define CODEINE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANILERID  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define MORPHINE  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define METHDON   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define STADOL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANALNEWA  229 "Librax" 326 "White cross" 422 "Motrin"
                       423 "Percocet" 424 "Fioricet" 427 "Darvocet"
                       428 "Execl" 429 "Frost" 433 "Paregoric" 434 "Vicodin"
                       991 "NEVER USED ANALGESICS" 998 "BLANK (NO ANSWER)" ;
label define ANALNEWB  424 "Fioricet" 991 "NEVER USED ANALGESICS"
                       998 "BLANK (NO ANSWER)" ;
label define ANLNOSP   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANLDKNAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANALAGE   91 "NEVER USED ANALGESICS" 94 "DONT KNOW"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define ANALTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED ANALGESICS" 94 "DONT KNOW"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define ANALREC   1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED ANALGESICS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define ANLALC    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS"
                       93 "DID NOT USE ANALGESIC IN PAST 12 MONTHS"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define ANLSED    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS"
                       93 "DID NOT USE ANALGESIC IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define ANLTRAN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS"
                       93 "DID NOT USE ANALGESIC IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define ANLSTM    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS"
                       93 "DID NOT USE ANALGESIC IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define ANLMJ     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS"
                       93 "DID NOT USE ANALGESIC IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define ANLINH    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS"
                       93 "DID NOT USE ANALGESIC IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define ANLCOC    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS"
                       93 "DID NOT USE ANALGESIC IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define ANLHAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS"
                       93 "DID NOT USE ANALGESIC IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define ANLOPT    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS"
                       93 "DID NOT USE ANALGESIC IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define ANLNONE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS"
                       93 "DID NOT USE ANALGESIC IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define MJOPP     91 "NEVER HAD CHANCE TO TRY MARIJUANA" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define MJAGE     91 "NEVER USED MARIJUANA" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define MJTOT     1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED MARIJUANA" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define MJREC     1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED MARIJUANA" ;
label define MJDAY30A  91 "NEVER USED MARIJUANA" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define MJAV30A   91 "NEVER USED MARIJUANA" 94 "DONT KNOW" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define MJAMT30A  1 "Less than 10 joints in the past 30 days"
                       2 "10 to 20 joints in the past 30 days"
                       3 "About 1 ounce in the past 30 days"
                       4 "About 2 ounces in the past 30 days"
                       5 "3 to 4 ounces in the past 30 days"
                       6 "5 to 6 ounces in the past 30 days"
                       7 "Unspecified but > 6 ounces in the past 30 days"
                       8 "7 ounces" 10 "10 ounces" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       94 "DONT KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define MJALC30A  1 "Always drank alcohol when used marijuana"
                       2 "More than half the time" 3 "About half the time"
                       4 "Less than half the time" 5 "One or two times"
                       6 "NEVER DRANK ALCOHOL W/MARIJUANA IN PAST"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define MJYRFREQ  1 "Several times a day" 2 "Daily"
                       3 "Almost daily (3 to 6 days a week)"
                       4 "1 or 2 days a week"
                       5 "Several times a month (about 25 to 51 days)"
                       6 "1 to 2 times a month (12 to 24 days a year)"
                       7 "Every other month or so (6 to 11 days a year)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 or 2 days in the past 12 months"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define MJALC     1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS" ;
label define MJSED     1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS" ;
label define MJTRAN    1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS" ;
label define MJSTM     1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS" ;
label define MJANAL    1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS" ;
label define MJINH     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS" ;
label define MJCOC     1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS" ;
label define MJHAL     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS" ;
label define MJOPT     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS" ;
label define MJNONE    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS" ;
label define AS7READ   1 "Wants interviewer to read questions"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK" ;
label define INHAGE    91 "NEVER USED INHALANTS" 94 "DONT KNOW" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define GAS       1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA" ;
label define SPPAINT   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA" ;
label define AEROS     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA" ;
label define GLUE      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA" ;
label define SOLVENT   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA" ;
label define AMYLNIT   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA" ;
label define ETHER     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA" ;
label define NITOXID   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA" ;
label define CLEFLU    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA" ;
label define INHNEWA   339 "Amphetamines (speed)"
                       511 "Markers, Felt-tip pens" 512 "Rush, Incense"
                       513 "Tulio" 515 "Vicks" 516 "Freon" 518 "Nail Polish"
                       519 "Helium" 805 "Cocaine, Coke"
                       991 "NEVER USED INHALANTS" 995 "BAD DATA" 998 "BLANK" ;
label define INHNEWB   511 "Markers, Felt-tip pens"
                       991 "NEVER USED INHALANTS" 995 "BAD DATA" 998 "BLANK" ;
label define INHNOSP   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA" ;
label define INHTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define GAS30A    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       95 "BAD DATA" ;
label define SPPAN30A  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       95 "BAD DATA" ;
label define AEROS30A  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       95 "BAD DATA" ;
label define GLUE30A   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       95 "BAD DATA" ;
label define SOLVN30A  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       95 "BAD DATA" ;
label define AMLNT30A  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       95 "BAD DATA" ;
label define ETHER30A  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       95 "BAD DATA" ;
label define NOX30A    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       95 "BAD DATA" ;
label define CLFL30A   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       95 "BAD DATA" ;
label define INNEW30A  511 "Markers, Felt-tip pens" 512 "Rush, Incense"
                       516 "Freon" 519 "Helium" 805 "Cocaine, Coke"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       995 "BAD DATA" 998 "BLANK" ;
label define INNEW30B  339 "Amphetamines (speed)" 991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       995 "BAD DATA" 998 "BLANK" ;
label define IN30NOSP  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS" ;
label define INH30NO   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED INHALANTS" ;
label define INHDY30A  91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define INHREC    1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHEFF    1 "Enough to feel it a little"
                       2 "Enough to feel it a lot" 3 "Enough to get high"
                       4 "Enough so that you staggered or dropped"
                       5 "Enough to feel you were going to pass out"
                       6 "Something else - unspecified"
                       7 "Didnt feel it, didnt use much"
                       8 "Sniffed out of curiosity once"
                       9 "Enough to make eyes water"
                       10 "Enough for a headrush"
                       11 "Just enough to say I did it - no feeling"
                       12 "Didnt feel it just like the smell"
                       91 "NEVER USED INHALANTS" 94 "DONT KNOW" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define INHPO     1 "Yes" 2 "No" 91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define INHQNC1   1 "QUESTION 1 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC2   2 "QUESTION 2 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC3   3 "QUESTION 3 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC4   4 "QUESTION 4 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC5   5 "QUESTION 5 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC6   6 "QUESTION 6 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC7   7 "QUESTION 7 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC8   8 "QUESTION 8 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC9   9 "ALL QUESTIONS WERE CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHANSY   1 "Yes" 2 "No" 98 "BLANK" ;
label define COCOPP    91 "NEVER HAD A CHANCE TO TRY COCAINE" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define COCAGE    91 "NEVER USED COCAINE" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define COCTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED COCAINE" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define COCREC    1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED COCAINE" ;
label define COCUS30A  91 "NEVER USED COCAINE" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define COC30ALC  1 "Always drank alcohol when used cocaine"
                       2 "More than half the time" 3 "About half the time"
                       4 "Less than half the time" 5 "One or two times"
                       6 "Never drank alcohol w/cocaine in past 30 days"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS" 95 "BAD DATA" ;
label define COCYRFRQ  1 "Daily" 2 "Almost daily (3 to 6 days a week)"
                       3 "1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define COCALC    1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCSED    1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCTRAN   1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCSTM    1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCANAL   1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCINH    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCMJ     1 "Response circled" 2 "Response not circled"
                       3 "Joint use of these two drugs LOGICALLY IMPUTED"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCHAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCOPT    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCNONE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCSNIFF  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       95 "BAD DATA" ;
label define COCSWAL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       95 "BAD DATA" ;
label define COCIV     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS" ;
label define FREEBASE  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       95 "BAD DATA" ;
label define COCNEWA   6 "Lasing joints and bongs" 7 "On my gums"
                       8 "Freeze, put on tongue, etc" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define COCNOSP   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       95 "BAD DATA" ;
label define CONDLREC  1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago" 91 "NEVER USED COCAINE"
                       93 "NEVER USED COCAINE WITH A NEEDLE"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define CRAKREC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       91 "NEVER USED CRACK" 98 "BLANK (NO ANSWER)" ;
label define CRKAM30A  993 "DID NOT USE CRACK IN PAST 30 DAYS" 995 "BAD DATA"
                       998 "BLANK (NO ANSWER)" ;
label define CRAKBUCK  9993 "DID NOT USE CRACK IN PAST 30 DAYS"
                       9994 "DONT KNOW" 9995 "BAD DATA"
                       9998 "BLANK (NO ANSWER)" ;
label define COCAM30A
                       1 "Less than 1/4 gram (about 4 big lines) past 30 days"
                       2 "About 1/4 gram in the past 30 days"
                       3 "About 1/2 gram in the past 30 days"
                       4 "About 1 gram in the past 30 days"
                       5 "About 2 grams in the past 30 days"
                       6 "About 3 grams in the past 30 days"
                       7 "Unspecified but >3 grams in past 30 days"
                       8 "4 grams in the past 30 days"
                       9 "5 grams in the past 30 days"
                       10 "7 grams in the past 30 days"
                       11 "8 grams in the past 30 days"
                       12 "14 grams in the past 30 days"
                       13 "28 grams in the past 30 days"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS"
                       94 "DONT KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define COCBUCK   9991 "NEVER USED COCAINE"
                       9993 "DID NOT USE COCAINE IN PAST 30 DAYS"
                       9994 "DONT KNOW" 9995 "BAD DATA"
                       9998 "BLANK (NO ANSWER)" ;
label define AS9READ   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself" 98 "BLANK" ;
label define LSD       1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED HALLUCINOGENS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define PEYOTE    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED HALLUCINOGENS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define MESC      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED HALLUCINOGENS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define PSILCY    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED HALLUCINOGENS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define PCP       1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED HALLUCINOGENS" 98 "BLANK (NO ANSWER)" ;
label define ECSTASY   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED HALLUCINOGENS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define HALNEWA   609 "Jimson Weed" 610 "Crystal T"
                       612 "Happy Stick, Shermstick" 613 "Duckweed" 614 "MDA"
                       615 "Homemade drugs" 616 "DMT"
                       617 "Morning glory seeds" 703 "Opium"
                       802 "THC, Cannabinol" 991 "NEVER USED HALLUCINOGENS"
                       995 "BAD DATA" 998 "BLANK" ;
label define HALNOSP   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED HALLUCINOGENS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define HALLOPP   91 "NEVER HAD A CHANCE TO TRY HALLUCINOGENS"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define HALLAGE   91 "NEVER USED HALLUCINOGENS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define HALLTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED HALLUCINOGENS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define HALLREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED HALLUCINOGENS" 98 "BLANK (NO ANSWER)" ;
label define HAL30USE  91 "NEVER USED HALLUCINOGENS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define PCPREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED PCP" 98 "BLANK (NO ANSWER)" ;
label define PCPFLASH  1 "Response circled" 2 "Response not circled"
                       6 "Never had any reaction when used PCP"
                       91 "NEVER USED PCP" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define PCPSENSE  1 "Response circled" 2 "Response not circled"
                       6 "Never had any reaction when used PCP"
                       91 "NEVER USED PCP" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define PCPFEELV  1 "Response circled" 2 "Response not circled"
                       6 "Never had any reaction when used PCP"
                       91 "NEVER USED PCP" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define PCPACTV   1 "Response circled" 2 "Response not circled"
                       6 "Never had any reaction when used PCP"
                       91 "NEVER USED PCP" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define PCPNEWA   6 "Never had any reaction when used PCP" 7 "Paranoid"
                       8 "Numbness" 9 "Like an acid high"
                       10 "Trouble walking" 11 "Felt weak, full of laughter"
                       12 "Sat in a chair and looked like a zombie"
                       13 "Knocked out, passed out" 14 "Energetic"
                       16 "Things were moving" 17 "Felt really funny, weird"
                       18 "Didnt want to drive" 19 "Talking and speeding"
                       20 "Hallucination" 21 "Felt sick - headache"
                       23 "Day after effects - lasted too long"
                       24 "Memory loss" 25 "Panic" 27 "Heightened awareness"
                       28 "In a dream world" 30 "Felt like you were dying"
                       31 "Enjoyed the trip" 32 "Got sick"
                       33 "A foot above the ground" 91 "NEVER USED PCP"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define PCPNEWB   6 "Never had a reaction when used PCP"
                       21 "Felt sick - headache" 22 "Alive" 25 "Panic"
                       27 "Heightened awareness" 29 "Crying spells"
                       34 "High on life" 35 "Things slowed down"
                       36 "Relaxed and happy" 91 "NEVER USED PCP"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define PCPNEWC   6 "Never had any reaction to PCP"
                       13 "Knocked out, passed out" 26 "Dizziness"
                       91 "NEVER USED PCP" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define PCPNOSP   1 "Response circled" 2 "Response not circled"
                       6 "Never had any reaction when used PCP"
                       91 "NEVER USED PCP" 98 "BLANK (NO ANSWER)" ;
label define PCPNORCT  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED PCP" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define HALLQCL   1 "Yes" 2 "No/Not Sure" 98 "BLANK" ;
label define AS10READ  1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself" 98 "BLANK" ;
label define HEROPP    91 "NEVER HAD A CHANCE TO TRY HEROIN" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define HERAGE    91 "NEVER USED HEROIN" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define HERTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED HEROIN" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define HERREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOCIGALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED HEROIN" 98 "BLANK (NO ANSWER)" ;
label define HER30USE  91 "NEVER USED HEROIN" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define HERNEEDL  1 "Yes, have used heroin with a needle"
                       2 "No, have used heroin, but not with a needle"
                       91 "NEVER USED HEROIN" 98 "BLANK (NO ANSWER)" ;
label define HRNDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago" 91 "NEVER USED HEROIN"
                       93 "NEVER USED HEROIN WITH A NEEDLE"
                       98 "BLANK (NO ANSWER)" ;
label define AS11READ  1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself" 98 "BLANK" ;
label define NODRUGS   1 "Response circled" 2 "Response not circled"
                       95 "BAD DATA" ;
label define CDCIG     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CDALC     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CDSED     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CDTRAN    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CDSTM     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CDANAL    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CDMJ      1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CDINH     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CDCOC     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CDHALL    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CDHER     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CDOTHOP   1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CDNONE    1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EFFCIG    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EFFALC    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EFFSED    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EFFTRAN   1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EFFSTM    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EFFANAL   1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EFFMJ     1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EFFINH    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EFFCOC    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EFFHALL   1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EFFHER    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EFFOTHOP  1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EFFNONE   1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define UDAYCIG   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define UDAYALC   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define UDAYSED   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define UDAYTRAN  1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define UDAYSTM   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define UDAYANAL  1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define UDAYMJ    1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define UDAYINH   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define UDAYCOC   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define UDAYHALL  1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define UDAYHER   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define UDAYOTH   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define UDAYNONE  1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPCIG    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPALC    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPSED    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPTRAN   1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPSTM    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPANAL   1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPMJ     1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPINH    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPCOC    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPHALL   1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPHER    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPOTHOP  1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPNONE   1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WSCIG     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WSALC     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WSSED     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WSTRAN    1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WSSTM     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WSANAL    1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WSMJ      1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WSINH     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WSCOC     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WSHALL    1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WSHER     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WSOTHOP   1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WSNONE    1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SHRNDLMO  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NRSHRNDL  98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CLEANNDL  1 "Threw away needle and syringe after use"
                       2 "Boiled works after use"
                       3 "Disinfected works with bleach"
                       4 "Disinfected works with alcohol"
                       5 "Washed works with water(fresh from tap)"
                       6 "Rinsed works with water other users did not use"
                       7 "Rinsed works with water other users may have used"
                       8 "Some other method - NOT SPECIFIED"
                       9 "Did not clean works, but did reuse them"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SHRWMALE  1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SHRWSEXP  1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SHRWRACE  1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define RSNNOSHR  1 "Concern about hepatitis" 2 "Concern about AIDS"
                       3 "Concern about infections"
                       4 "Own needle works better or is in better condition"
                       5 "Nobody you use with shares"
                       6 "Somebody else would break or abuse your needle"
                       7 "Youve just never shared needles"
                       8 "Some other method - NOT SPECIFIED"
                       9 "Do not like needles, dont like to stick myself"
                       10 "Didnt want to"
                       11 "It is stupid, horrifying, screws up life"
                       12 "Reformed drug user" 13 "Alone"
                       14 "Know what needle can do, could never do that"
                       15 "Never had a needle"
                       91 "DID NOT USE DRUGS IN PAST 30 DAYS" 92 "ILLEGIBLE"
                       93 "DID NOT USE NEEDLES IN PAST 30 DAYS" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SHRNDLMO = 1, 99)" ;
label define NOBOOZYR  1 "Response circled" 2 "Response not circled"
                       95 "BAD DATA (Past yr alcohol use recorded elsewhere)" ;
label define ALCAGGR   1 "Yes" 2 "No" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCARGUM  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCABSNT  1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCHIGH   1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCJOB    1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCMATCD  1 "Yes" 2 "No" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCRELCD  1 "Yes" 2 "No" 95 "BAD DATA" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCFRDCD  1 "Yes" 2 "No" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCTOSS   1 "Yes" 2 "No" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCHOLIC  1 "Yes" 2 "No" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCDRUNK  1 "Yes" 2 "No" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCINTOX  1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCREM    1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCQUICK  1 "Yes" 2 "No" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCMORN   1 "Yes" 2 "No" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCSHOOK  1 "Yes" 2 "No" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCALONE  1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCBRKPM  1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AS13NONE  1 "Response circled" 2 "Response not circled"
                       95 "BAD DATA" ;
label define DRDEPRSS  1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DEPDRG1A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       208 "Centrax" 209 "Xanax"
                       322 "Methamphetamine (speed or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed)" 401 "Darvon"
                       409 "Tylenol with Codeine"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 995 "BAD DATA"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define DEPDRG2A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       322 "Methamphetamine (speed or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed)" 418 "Methadone"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 815 "Coffee"
                       995 "BAD DATA" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define DEPDRG3A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol" 809 "Pills" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define DEPDRG4A  510 "OTHER Inhalant, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 807 "Alcohol" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define DEPDRG5A  702 "Heroin" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define DRARGUM   1 "Yes" 2 "No" 95 "BAD DATA" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ARGDRG1A  113 "Halcion" 322 "Methamphetamine (speed or crank)"
                       339 "Amphetamines (speed)"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 995 "BAD DATA"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define ARGDRG2A  322 "Methamphetamine (speed or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed)" 418 "Methadone"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 815 "Coffee"
                       995 "BAD DATA" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define ARGDRG3A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium" 702 "Heroin" 805 "Cocaine, Coke"
                       809 "Pills" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define ARGDRG4A  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 807 "Alcohol" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define ARGDRG5A  702 "Heroin" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define DRALONE   1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALNDRG1A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium" 322 "Methamphetamine (speed or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed)"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 995 "BAD DATA"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define ALNDRG2A  201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       339 "Amphetamines (speed)" 418 "Methadone"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol" 813 "Cigarettes, Tobacco"
                       815 "Coffee" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define ALNDRG3A  702 "Heroin" 805 "Cocaine, Coke" 807 "Alcohol"
                       809 "Pills" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define ALNDRG4A  510 "OTHER Inhalant, NOT SPECIFIED" 803 "Marijuana"
                       807 "Alcohol" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define ALNDRG5A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       702 "Heroin" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define DRANX     1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANXDRG1A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium" 208 "Centrax" 309 "Didrex" 313 "Fastin"
                       315 "Voranil" 322 "Methamphetamine (speed or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       332 "Ephedrine, Caffeine, No-Doz, Vivarin"
                       339 "Amphetamines (speed)" 401 "Darvon"
                       409 "Tylenol with Codeine" 415 "Codeine"
                       509 "Correction fluids, degreasers, cleaning"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 618 "Acid paper"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol" 812 "Cigars"
                       813 "Cigarettes, Tobacco" 994 "DONT KNOW"
                       995 "BAD DATA" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define ANXDRG2A  201 "Valium" 312 "Ionamin" 313 "Fastin"
                       322 "Methamphetamine (speed or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed)" 348 "Crystal"
                       418 "Methadone" 601 "LSD (acid, white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 815 "Coffee" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define ANXDRG3A  209 "Xanax" 322 "Methamphetamine (speed or crank)"
                       339 "Amphetamines (speed)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       809 "Pills" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define ANXDRG4A  324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 807 "Alcohol" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define ANXDRG5A  702 "Heroin" 803 "Marijuana" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define DRHEALTH  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLTDRG1A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       322 "Methamphetamine (speed or crank)"
                       339 "Amphetamine (speed)"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       605 "PCP (angel dust, phencyclidine)" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       811 "Muscle relaxers" 813 "Cigarettes, Tobacco"
                       814 "Caffeine" 995 "BAD DATA" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define HLTDRG2A  324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed)" 418 "Methadone"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 815 "Coffee"
                       995 "BAD DATA" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define HLTDRG3A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       809 "Pills" 813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define HLTDRG4A  324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       510 "OTHER Inhalant, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 807 "Alcohol" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define HLTDRG5A  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define DRNTHINK  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NTKDRG1A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       208 "Centrax" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or crank)"
                       339 "Amphetamines (speed)" 409 "Tylenol with Codeine"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       509 "Correction fluids, degreasers, cleaning"
                       601 "LSD (acid, white lightning)" 603 "Mescaline"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 995 "BAD DATA"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define NTKDRG2A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed)" 348 "Crystal" 415 "Codeine"
                       418 "Methadone"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 995 "BAD DATA"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define NTKDRG3A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       339 "Amphetamines (speed)"
                       601 "LSD (acid, white lightning)"
                       607 "OTHER Hallucinogen NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define NTKDRG4A  221 "OTHER Tranquilizer, NOT SPECIFID"
                       601 "LSD (acid, white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 807 "Alcohol" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define NTKDRG5A  324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define DRUPSET   1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define UPSDRG1A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       208 "Centrax" 322 "Methamphetamine (speed or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       332 "Ephedrine, Caffeine, No-Doz, Vivarin"
                       339 "Amphetamines (speed)" 418 "Methadone"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 811 "Muscle relaxers"
                       813 "Cigarettes, Tobacco" 815 "Coffee" 995 "BAD DATA"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define UPSDRG2A  201 "Valium" 312 "Ionamin"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 995 "BAD DATA"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define UPSDRG3A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       315 "Voranil" 339 "Amphetamines (speed)" 702 "Heroin"
                       805 "Cocaine, Coke" 807 "Alcohol" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define UPSDRG4A  221 "OTHER Tranquilizer, NOT SPECIFIED" 702 "Heroin"
                       807 "Alcohol" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define UPSDRG5A  324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define DRLSWORK  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LSWDRG1A  201 "Valium" 322 "Methamphetamine (speed or crank)"
                       348 "Crystal" 420 "OTHER Analgesic, NOT SPECIFIED"
                       425 "Advil" 601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 613 "Duckweed"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 812 "Cigars" 813 "Cigarettes, Tobacco"
                       995 "BAD DATA" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define LSWDRG2A  418 "Methadone" 803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 995 "BAD DATA"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define LSWDRG3A  339 "Amphetamines (speed)" 805 "Cocaine, Coke"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define LSWDRG4A  601 "LSD (acid, white lightning)" 803 "Marijuana"
                       807 "Alcohol" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define LSWDRG5A  998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define DRSUSPIC  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SSPDRG1A  201 "Valium" 307 "Tenuate" 318 "Ritalin"
                       322 "Methamphetamine (speed or crank)"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 994 "DONT KNOW"
                       995 "BAD DATA" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define SSPDRG2A  324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       418 "Methadone" 510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define SSPDRG3A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       339 "Amphetamines (speed)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define SSPDRG4A  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       803 "Marijuana" 807 "Alcohol" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define SSPDRG5A  324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define DRCOPE    1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CPEDRG1A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium" 312 "Ionamin"
                       322 "Methamphetamine (speed or crank)"
                       339 "Amphetamines (speed)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       813 "Cigarettes, Tobacco" 995 "BAD DATA" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define CPEDRG2A  315 "Voranil" 348 "Crystal"
                       601 "LSD (acid, white lightning)" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define CPEDRG3A  339 "Amphetamines (speed)"
                       604 "Psilocybin (mushrooms)" 702 "Heroin"
                       805 "Cocaine, Coke" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define CPEDRG4A  702 "Heroin" 807 "Alcohol" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define CPEDRG5A  998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define DREMGMED  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define EMDRG1A   120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       339 "Amphetamines (speed)" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol" 813 "Cigarettes, Tobacco"
                       995 "BAD DATA" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define EMDRG2A   803 "Marijuana" 805 "Cocaine, Coke" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define EMDRG3A   702 "Heroin" 805 "Cocaine, Coke" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define EMDRG4A   998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define EMDRG5A   998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define RSKPKCIG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKMJOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKMJREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKTRYPCP  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKPCPREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKTRYHER  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKHERREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKTRYCOC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKCOCOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKCOCREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKCRKOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RK2DRINK  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RK5DRINK  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKBINGE  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HIGHBP    1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK" ;
label define BPMED     1 "Yes" 2 "No" 94 "DONT KNOW" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define WALKPAIN  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK" ;
label define TIMEPAIN  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK" ;
label define UPSHOR    1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK" ;
label define ASTHMA    1 "Yes" 2 "No" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK" ;
label define TRPSYCH   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK" ;
label define HEART     1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK" ;
label define FLU       1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK" ;
label define ALLERG    1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK" ;
label define HOSPYR    1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK" ;
label define SOREYR    1 "Yes" 2 "No" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK" ;
label define RUNNYYR   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK" ;
label define COUGHYR   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK" ;
label define PHLEGMYR  1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK" ;
label define HEALTHYR  1 "Excellent" 2 "Very good" 3 "Good" 4 "Fair" 5 "Poor"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK" ;
label define MARITAL   1 "Married" 2 "Widowed" 3 "Divorced or separated"
                       4 "Has never married" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define NOMARR    95 "BAD DATA" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKSTAT  1 "Working full-time, 35 hours or more a week"
                       2 "Working part-time, less than 35 hours a week"
                       3 "Have job but out: illness/leave/furlough"
                       4 "Unemployed or laid off and looking for work"
                       5 "Unemployed and not looking for work"
                       6 "Full-time homemaker only" 7 "In school only"
                       8 "Retired" 9 "Disabled, not able to work"
                       10 "Something else (NOT SPECIFIED)"
                       11 "Unable to work - taking care of ill relatives"
                       12 "About to start work"
                       13 "Contracts for work (eg.sician)"
                       14 "Welfare (AFDC)"
                       15 "Out of work - Termination - Injury"
                       16 "Just got out of school"
                       17 "Just returned to United States" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED" 98 "BLANK" ;
label define PAYMO     91 "NEVER WORKED FOR PAY" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PAYYR     91 "NEVER WORKED FOR PAY" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NO5JOB    92 "ILLEGIBLE" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKDAYS  95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKBLAH  97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CWE       1 "Respondent" 2 "Someone else (NOT SPECIFIED)"
                       3 "No one" 4 "Spouse" 5 "Live-in partner, fiance"
                       6 "Mother" 7 "Father" 8 "Daughter" 9 "Son" 10 "Sister"
                       11 "Brother" 12 "Grandmother" 13 "Grandfather"
                       14 "Other female blood relative"
                       15 "Other male blood relative" 16 "Mother-in-law"
                       17 "Father-in-law" 18 "Other female in-law"
                       19 "Other male in-law" 20 "Close female friend"
                       21 "Close male friend" 22 "Other female acquaintance"
                       23 "Other male acquaintance, ex-husband"
                       24 "Step-mother" 25 "Step-father"
                       28 "Friend (sex unspecified)" 29 "Foster son"
                       31 "Parents (unspecified)"
                       32 "Foster mother, female guardian"
                       33 "Foster father, male guardian"
                       34 "Guardian (sex unspecified)" 35 "Grandparents"
                       94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define FULLPART  1 "Full-time" 2 "Part-time"
                       3 "Chief source of income does not work"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define EDUC      0 "No schooling" 1 "First Grade" 2 "Second grade"
                       3 "Third grade" 4 "Fourth grade" 5 "Fifth grade"
                       6 "Sixth grade" 7 "Seventh Grade" 8 "Eighth grade"
                       9 "Ninth grade" 10 "Tenth grade" 11 "Eleventh grade"
                       12 "Twelfth grade" 13 "One year college"
                       14 "2 years college" 15 "3 years college"
                       16 "4 years college" 17 "Graduate/professional school"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK" ;
label define ENROLLD   1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK" ;
label define SCHPLANS  1 "Has plans to enroll in a school in future"
                       2 "Has completed all schooling" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define STUDENT   1 "A full-time student" 2 "A part-time student"
                       97 "REFUSED" 98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define SCHDAYS   95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKIPPED   95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MILES     99991 "HAS NEVER DRIVEN A MOTOR VEHICLE"
                       99994 "DONT KNOW" 99995 "BAD DATA"
                       99996 "MULTIPLE RESPONSE" 99997 "REFUSED"
                       99998 "BLANK (NO ANSWER)" 99999 "LEGITIMATE SKIP" ;
label define ACCID     1 "Yes" 2 "No" 3 "Did not drive in past 12 months"
                       95 "BAD DATA" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define NOCHILD   97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MOTHER    0 "No" 1 "Yes" 97 "REFUSED" ;
label define STEPMOM   0 "No" 1 "Yes" 97 "REFUSED" ;
label define FATHER    0 "No" 1 "Yes" 97 "REFUSED" ;
label define STEPDAD   0 "No" 1 "Yes" 97 "REFUSED" ;
label define SPOUSE    0 "No" 1 "Yes" 97 "REFUSED" ;
label define INLAW     93 "RELATION INDICATED, NO COUNT RECORDED"
                       97 "REFUSED" ;
label define OWNCHILD  93 "RELATION INDICATED, NO COUNT RECORDED"
                       97 "REFUSED" ;
label define STEPCHLD  97 "REFUSED" ;
label define BROSIS    93 "RELATION INDICATED, NO COUNT RECORDED"
                       97 "REFUSED" ;
label define OTHREL    93 "RELATION INDICATED, NO COUNT RECORDED"
                       97 "REFUSED" ;
label define FRIENDS   97 "REFUSED" ;
label define OTHERNON  97 "REFUSED" ;
label define SERVICE   1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define MILSTAT   1 "On extended active duty in the Armed Forces"
                       2 "In a Reserves component"
                       3 "Separated/retired from Reserves or active duty"
                       95 "BAD DATA" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define MOVDAWAY  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK" ;
label define DORM      94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MILBASE   94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HOSP      94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TELNO     95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MOVES     94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INCOME    1 "No personal earnings" 2 "Yearly under $5,000"
                       3 "Yearly $5,000 to $6,999"
                       4 "Yearly $7,000 to $8,999"
                       5 "Yearly $9,000 to $11,999"
                       6 "Yearly $12,000 to $14,999"
                       7 "Yearly $15,000 to $19,999"
                       8 "Yearly $20,000 to $24,999"
                       9 "Yearly $25,000 to $29,999"
                       10 "Yearly $30,000 to $39,999"
                       11 "Yearly $40,000 to $50,000"
                       12 "Yearly more than $50,000" 94 "DONT KNOW"
                       95 "BAD DATA" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define BAP       1 "AM" 2 "PM" ;
label define EAP       1 "AM" 2 "PM" ;
label define LANGVER   1 "English" 2 "Spanish" ;
label define UNDINT    1 "No difficulty-no language or reading problem"
                       2 "Just a little difficulty-almost no lang/readg prob"
                       3 "Fair amount of difficulty-some lang/readg prob"
                       4 "A lot of difficulty-considerable lang/readg prob"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define COOPINT   1 "Very cooperative" 2 "Fairly cooperative"
                       3 "Not very cooperative" 4 "Openly hostile"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define PRIVACY   1 "Completely private-no one present/able to overhear"
                       3 "Minor distractions"
                       5 "Person(s) in room or listening 1/3 of the time"
                       7 "Serious interruptions more than half the time"
                       9 "Constant presence of other person(s)"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       98 "BLANK (NO ANSWER)" ;
label define PPRES     1 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SPRES     2 "Response Circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PARPRES   3 "Response Circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OARPRES   4 "Response Circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OAPRES    5 "Response Circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CPRES     6 "Response Circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OPRESSPA  8 "Friend (unspecified sex or age)"
                       9 "Female friend (age unspecified)"
                       10 "Male friend (age unspecified)"
                       11 "Female relative (age unspecified)"
                       12 "Male relative (age unspecified)" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define OPRESSPB  9 "Female friend (age unspecified)"
                       12 "Male relative (age unspecified)"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define OPRESNSP  7 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define REGION    1 "Northeast" 2 "North Central" 3 "South" 4 "West" ;
label define DIVISION  1 "New England" 2 "Middle Atlantic"
                       3 "East North Central" 4 "West North Central"
                       5 "South Atlantic" 6 "East South Central"
                       7 "West South Central" 8 "Mountain" 9 "Pacific" ;
label define IIAGE     1 "Age calculated from questionnaire"
                       2 "Age taken from screener" 3 "Age imputed" ;
label define AGEGR     1 "12-17 years" 2 "18-25 years" 3 "26-34 years"
                       4 "35+ years" ;
label define ORAGEGR   1 "Age Group taken from questionnaire"
                       2 "Age Group taken from screener" ;
label define SEX       1 "Male" 2 "Female" ;
label define ORSEX     1 "Sex taken from questionnaire"
                       2 "Sex taken from screener" ;
label define IRRACE    1 "American Indian or Alaskan Native"
                       2 "Asian or Pacific Islander" 3 "Black" 4 "White" ;
label define IIRACE    1 "Race taken from questionnaire" 2 "Race imputed" ;
label define IRHOIND   1 "Hispanic" 2 "Not Hispanic" ;
label define IIHOIND   1 "Hispanic Origin taken from questionnaire"
                       2 "Hispanic Origin imputed" ;
label define IRHOGRP   1 "Puerto Rican" 2 "Mexican" 3 "Cuban" 4 "Other"
                       9 "Non-Hispanic" ;
label define IIHOGRP   1 "Hispanic-Origin Group taken from questionnaire"
                       2 "Hispanic-Origin Group imputed" ;
label define IRALCRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used alcohol" ;
label define IIALCRC   1 "Questionnaire data" 2 "Imputed data" ;
label define IRMJRC    1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago" 9 "Never used marijuana" ;
label define IIMJRC    1 "Questionnaire data" 2 "Imputed data" ;
label define IRCOCRC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago" 9 "Never used cocaine" ;
label define IICOCRC   1 "Questionnaire data" 2 "Imputed data" ;
label define IRSEDRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used sedatives" ;
label define IISEDRC   1 "Questionnaire data" 2 "Imputed data" ;
label define IRTRNRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used tranquilizers" ;
label define IITRNRC   1 "Questionnaire data" 2 "Imputed data" ;
label define IRSTMRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used stimulants" ;
label define IISTMRC   1 "Questionnaire data" 2 "Imputed data" ;
label define IRANLRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used analgesics" ;
label define IIANLRC   1 "Questionnaire data" 2 "Imputed data" ;
label define IRCIGRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never smoked cigarettes" ;
label define IICIGRC   1 "Questionnaire data" 2 "Imputed data" ;
label define IROTBRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 years ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       9 "Never used smokeless tobacco" ;
label define IIOTBRC   1 "Questionnaire data" 2 "Imputed data" ;
label define IRINHRC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago" 9 "Never used inhalants" ;
label define IIINHRC   1 "Questionnaire data" 2 "Imputed data" ;
label define IRCRKRC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago" 9 "Never used crack" ;
label define IICRKRC   1 "Questionnaire data" 2 "Imputed data" ;
label define IRHALRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used hallucinogens" ;
label define IIHALRC   1 "Questionnaire data" 2 "Imputed data" ;
label define IRHERRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used heroin" ;
label define IIHERRC   1 "Questionnaire data" 2 "Imputed data" ;
label define IRPCPRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used PCP" ;
label define IIPCPRC   1 "Questionnaire data" 2 "Imputed data" ;
label define IRALCFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IIALCFQ   1 "Questionnaire data" 2 "Imputed data" ;
label define IRMJFQ    1 "Used several times per day in past year"
                       2 "Used daily in past year"
                       3 "Used almost daily in past year"
                       4 "Used 1-2 days per week in past year"
                       5 "Used several times per month in past year"
                       6 "Used 1-2 times per month in past year"
                       7 "Used every other month in past year"
                       8 "Used 3-5 times in past year"
                       9 "Used 1-2 times in past year"
                       10 "Never used or did not use in the past year" ;
label define IIMJFQ    1 "Questionnaire data" 2 "Imputed data" ;
label define IRCOCFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times per month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IICOCFQ   1 "Questionnaire data" 2 "Imputed data" ;
label define CATAGE    1 "12-17 years" 2 "18-25 years" 3 "26-34 years"
                       4 "35+ years" ;
label define CATAG2    1 "12-17 years" 2 "18-25 years" 3 "26+ years" ;
label define RACE      1 "White" 2 "Black" 3 "Hispanic" 4 "Other" ;
label define EDUCCAT   1 "Less than high school (EDUC = 0-11)"
                       2 "High school graduate (EDUC = 12)"
                       3 "Some college (EDUC = 13-15)"
                       4 "College graduate (EDUC = 16-17)" ;
label define EMPSTAT   1 "Full-time" 2 "Part-time" 3 "Unemployed" 4 "Other" ;
label define SMOKCOK   0 "No" 1 "Yes" ;
label define CONDLRC2  1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       7 "Never used cocaine with a needle" ;
label define HALFLAG   0 "Never used" 1 "Ever used" ;
label define HALYR     0 "Did not use in the past year"
                       1 "Used within the past year" ;
label define HALMON    0 "Did not use in the past month"
                       1 "Used within the past month" ;
label define PCPFLAG   0 "Never used" 1 "Ever used" ;
label define PCPYR     0 "Did not use in the past year"
                       1 "Used within the past year" ;
label define PCPMON    0 "Did not use in the past month"
                       1 "Used within the past month" ;
label define STMFLAG   0 "Never used" 1 "Ever used" ;
label define STMYR     0 "Did not use in the past year"
                       1 "Used within the past year" ;
label define STMMON    0 "Did not use in the past month"
                       1 "Used within the past month" ;
label define SEDFLAG   0 "Never used" 1 "Ever used" ;
label define SEDYR     0 "Did not use in the past year"
                       1 "Used within the past year" ;
label define SEDMON    0 "Did not use in the past month"
                       1 "Used within the past month" ;
label define TRQFLAG   0 "Never used" 1 "Ever used" ;
label define TRQYR     0 "Did not use in the past year"
                       1 "Used within the past year" ;
label define TRQMON    0 "Did not use in the past month"
                       1 "Used within the past month" ;
label define ANLFLAG   0 "Never used" 1 "Ever used" ;
label define ANLYR     0 "Did not use in the past year"
                       1 "Used within the past year" ;
label define ANLMON    0 "Did not use in the past month"
                       1 "Used within the past month" ;
label define ALCFLAG   0 "Never used" 1 "Ever used" ;
label define ALCYR     0 "Did not use in the past year"
                       1 "Used within the past year" ;
label define ALCMON    0 "Did not use in the past month"
                       1 "Used within the past month" ;
label define CIGFLAG   0 "Never used" 1 "Ever used" ;
label define CIGYR     0 "Did not use in the past year"
                       1 "Used within the past year" ;
label define CIGMON    0 "Did not use in the past month"
                       1 "Used within the past month" ;
label define SMKFLAG   0 "Never used" 1 "Ever used" ;
label define SMKYR     0 "Did not use in the past year"
                       1 "Used within the past year" ;
label define SMKMON    0 "Did not use in the past month"
                       1 "Used within the past month" ;
label define HERFLAG   0 "Never used" 1 "Ever used" ;
label define HERYR     0 "Did not use in the past year"
                       1 "Used within the past year" ;
label define HERMON    0 "Did not use in the past month"
                       1 "Used within the past month" ;
label define MRJFLAG   0 "Never used" 1 "Ever used" ;
label define MRJYR     0 "Did not use in the past year"
                       1 "Used within the past year" ;
label define MRJMON    0 "Did not use in the past month"
                       1 "Used within the past month" ;
label define COCFLAG   0 "Never used" 1 "Ever used" ;
label define COCYR     0 "Did not use in the past year"
                       1 "Used within the past year" ;
label define COCMON    0 "Did not use in the past month"
                       1 "Used within the past month" ;
label define CRKFLAG   0 "Never used" 1 "Ever used" ;
label define CRKYR     0 "Did not use in the past year"
                       1 "Used within the past year" ;
label define CRKMON    0 "Did not use in the past month"
                       1 "Used within the past month" ;
label define INHFLAG   0 "Never used" 1 "Ever used" ;
label define INHYR     0 "Did not use in the past year"
                       1 "Used within the past year" ;
label define INHMON    0 "Did not use in the past month"
                       1 "Used within the past month" ;
label define NEEDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       91 "NEVER USED A NEEDLE TO INJECT ANY DRUG"
                       98 "NEEDLE USE NOT INDICATED BUT 1+ SOURCE VAR BLANK" ;
label define NEDFLAG   0 "Never used" 1 "Ever used" ;
label define NEDYR     0 "Did not use in the past year"
                       1 "Used within the past year" ;
label define COCYRF    0 "Never used or did not use in past year"
                       1 "Any use within the past year" ;
label define COCMONF   0 "Did not use monthly/more past year"
                       1 "Used monthly or more often past year" ;
label define COCWKF    0 "Did not use weekly or more past year"
                       1 "Used weekly or more often past year" ;
label define ALCYRF    0 "Never used or not used in past year"
                       1 "Any use within the past year" ;
label define ALCMONF   0 "Did not use monthly/more past year (IRALCFQ = 6-9)"
                       1 "Used monthly or more often past year (IRALCFQ = 1-5)" ;
label define ALCWKF    0 "Did not use weekly or more past year"
                       1 "Used weekly or more in past year" ;
label define MRJYRF    0 "Never used or did not use in past year"
                       1 "Any use within the past year" ;
label define MRJMONF   0 "Did not use monthly/more past year"
                       1 "Used monthly or more in past year" ;
label define MRJWKF    0 "Did not use weekly/more past year"
                       1 "Used weekly or more in past year" ;
label define PSYFLAG2  0 "Never used" 1 "Ever used" ;
label define PSYYR2    0 "Did not use within past year" 1 "Used in past year" ;
label define PSYMON2   0 "Did not use in past month" 1 "Used in past month" ;
label define SUMFLAG   0 "Never used" 1 "Ever used" ;
label define SUMYR     0 "Did not use in past year" 1 "Used in past year" ;
label define SUMMON    0 "Did not use in past month" 1 "Used in past month" ;
label define MJOFLAG
                       0 "Never used MJ/has used both MJ & anoth illicit drug"
                       1 "Marijuana is only (illicit) drug ever used" ;
label define MJOYR2    0 "MJ not used past yr/Used MJ & othr drug pastyr"
                       1 "Marijuana is only (illicit) drug in pastyr" ;
label define MJOMON2
                       0 "MJ not used past mnth/Used MJ & othr drug past month"
                       1 "Marijuana only (illicit) drug in past mo" ;
label define CWEOCC2   990 "OCCUPATION NOT REPORTED" 994 "DONT KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ROCCUP2   990 "OCCUPATION NOT REPORTED" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define BUSINES2  990 "INDUSTRY NOT REPORTED" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CWEBUS2   990 "INDUSTRY NOT REPORTED" 994 "DONT KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define POPDEN    1 "1,000,000 or more in metropolitan area"
                       2 "50,000 to 999,999 in metropolitan area"
                       3 "Not a metropolitan area" ;
label define MRJMON2   1 "Did not use in past month"
                       2 "Used within the past month" ;
label define ALCMON2   1 "Did not use in the past month"
                       2 "Used within the past month" ;
label define CIGMON2   1 "Did not use in past month"
                       2 "Used within past month" ;
label define LSD2      0 "Never used hallucinogens" 1 "Ever used LSD" ;
label define PEYOTE2   0 "Never used hallucinogens" 1 "Ever used Peyote" ;
label define MESC2     0 "Never used hallucinogens" 1 "Ever used Mescaline" ;
label define PSILCY2   0 "Never used hallucinogens" 1 "Ever used Psilocybin" ;
label define GAS2      0 "Never inhaled" 1 "Ever inhaled" ;
label define SPPAINT2  0 "Never inhaled" 1 "Ever inhaled" ;
label define AEROS2    0 "Never inhaled" 1 "Ever inhaled" ;
label define GLUE2     0 "Never inhaled" 1 "Ever inhaled" ;
label define SOLVENT2  0 "Never inhaled" 1 "Ever inhaled" ;
label define AMYLNIT2  0 "Never inhaled" 1 "Ever inhaled" ;
label define ETHER2    0 "Never inhaled" 1 "Ever inhaled" ;
label define NITOXID2  0 "Never inhaled" 1 "Ever inhaled" ;
label define CLEFLU2   0 "Never inhaled" 1 "Ever inhaled" ;
label define COCSNIF2  0 "Never/no use in past 12 months"
                       1 "Sniffed/snorted in past 12 months" ;
label define FREEBAS2  0 "Never/no use past 12 months (FREEBASE= 2, 91, 93)"
                       1 "Freebased in past 12 months (FREEBASE = 1)" ;
label define COCSWAL2  0 "Never/no use in past 12 months (COCSWAL="
                       1 "Swallowed/drank in past 12 months" ;
label define COCIV2    0 "Never/no use in past 12 months"
                       1 "Injected in the past 12 months" ;
label define COCNEWA2  0 "Never/no use in past 12 months"
                       1 "Used other ways past 12 months" ;
label define MJTOT2    1 "Never used marijuana" 2 "1-2 times" 3 "3-10 times"
                       4 "11-99 times" 5 "100 or more times" 6 "Unknown" ;
label define COCTOT2   1 "Never used cocaine" 2 "1-2 times" 3 "3-10 times"
                       4 "11-99 times" 5 "100 or more times" 6 "Unknown" ;
label define MJTOT3    1 "1-2 times" 2 "3-10 times" 3 "11-99 times"
                       4 "100 or more times" 5 "Never used marijuana" ;
label define COCTOT3   1 "1-2 times" 2 "3-10 times" 3 "11-99 times"
                       4 "100 or more times" 5 "Never used cocaine" ;
label define MJDY30A2  1 "None or never used marijuana" 2 "1-2 days"
                       3 "3-4 days" 4 "5-19 days" 5 "20-30 days" 6 "Unknown" ;
label define ALCDAYS2  1 "None or never used alcohol" 2 "1-2 days"
                       3 "3-4 days" 4 "5-19 days" 5 "20-30 days" ;
label define RACESEX   1 "White male" 2 "Black male" 3 "Hispanic male"
                       4 "White female" 5 "Black female" 6 "Hispanic female" ;
label define NOTMARJ   0 "No" 1 "Yes" ;
label define EDUCCAT2  1 "Less than high school (CATAGE > 1 and ED"
                       2 "High school graduate (CATAGE > 1 and EDU"
                       3 "Some college" 4 "College graduate" ;
label define EMPSTAT2  1 "Full-time" 2 "Part-time" 3 "Unemployed" 4 "Other" ;
label define MJDY30A3  1 "1-2 days" 2 "3-4 days" 3 "5-19 days" 4 "20-30 days"
                       5 "None or never used marijuana" ;
label define ALCDAYS3  1 "None or never used alcohol" 2 "1-4 days"
                       3 "5-19 days" 4 "20-30 days" ;
label define DRINKER   0 "Never/no use alcohol in past 30 days"
                       1 "Used alcohol in past 30 days" ;
label define HVYDRK    0 "Never/no hvy use" 1 "Heavy alcohol use" ;
label define AVCIG2    1 "None or never smoked cigarettes"
                       2 "Currently smoke < a pack per day"
                       3 "Currently smoke a pack or more per day" ;
label define IRDEP     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRARG     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALN     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRANX     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRHLT     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRNTK     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRUPS     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRLSW     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRSSP     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRCPE     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IREMG     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRDEP1    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       208 "Centrax" 209 "Xanax"
                       322 "Methamphetamine (speed or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed)" 401 "Darvon"
                       409 "Tylenol with Codeine"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRDEP2    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       322 "Methamphetamine (speed or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed)" 418 "Methadone"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 815 "Coffee"
                       999 "LEGITIMATE SKIP" ;
label define IRDEP3    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol" 809 "Pills" 999 "LEGITIMATE SKIP" ;
label define IRDEP4    510 "OTHER Inhalant, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRDEP5    702 "Heroin" 999 "LEGITIMATE SKIP" ;
label define IRARG1    113 "Halcion" 322 "Methamphetamine (speed or crank)"
                       339 "Amphetamines (speed)"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRARG2    322 "Methamphetamine (speed or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed)" 418 "Methadone"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 815 "Coffee"
                       999 "LEGITIMATE SKIP" ;
label define IRARG3    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium" 702 "Heroin" 805 "Cocaine, Coke"
                       809 "Pills" 999 "LEGITIMATE SKIP" ;
label define IRARG4    221 "OTHER Tranquilizer, NOT SPECIFIED"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRARG5    702 "Heroin" 999 "LEGITIMATE SKIP" ;
label define IRALN1    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium" 322 "Methamphetamine (speed or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed)"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRALN2    201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       339 "Amphetamines (speed)" 418 "Methadone"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol" 813 "Cigarettes, Tobacco"
                       815 "Coffee" 999 "LEGITIMATE SKIP" ;
label define IRALN3    702 "Heroin" 805 "Cocaine, Coke" 807 "Alcohol"
                       809 "Pills" 999 "LEGITIMATE SKIP" ;
label define IRALN4    510 "OTHER INHALANT, NOT SPECIFIED" 803 "MARIJUANA"
                       807 "ALCOHOL" 999 "LEGITIMATE SKIP" ;
label define IRALN5    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       702 "HEROIN" 999 "LEGITIMATE SKIP" ;
label define IRANX1    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium" 208 "Centrax" 309 "Didrex" 313 "Fastin"
                       315 "Voranil" 322 "Methamphetamine (speed or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       332 "Ephedrine, Caffeine, No-Doz, Vivarin"
                       339 "Amphetamines (speed)" 401 "Darvon"
                       409 "Tylenol with Codeine" 415 "Codeine"
                       509 "Correction fluids, degreasers, cleaning"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 618 "Acid paper"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol" 812 "Cigars"
                       813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRANX2    201 "Valium" 312 "Ionamin" 313 "Fastin"
                       322 "Methamphetamine (speed or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed)" 348 "Crystal"
                       418 "Methadone" 601 "LSD (acid, white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 815 "Coffee"
                       999 "LEGITIMATE SKIP" ;
label define IRANX3    209 "Xanax" 322 "Methamphetamine (speed or crank)"
                       339 "Amphetamines (speed)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       809 "Pills" 999 "LEGITIMATE SKIP" ;
label define IRANX4    324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRANX5    702 "Heroin" 803 "Marijuana" 999 "LEGITIMATE SKIP" ;
label define IRHLT1    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       322 "Methamphetamine (speed or crank)"
                       339 "Amphetamine (speed)"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       605 "PCP (angel dust, phencyclidine)" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       811 "Muscle relaxers" 813 "Cigarettes, Tobacco"
                       814 "Caffeine" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define IRHLT2    324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed)" 418 "Methadone"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 815 "Coffee"
                       999 "LEGITIMATE SKIP" ;
label define IRHLT3    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       809 "Pills" 813 "Cigarettes, Tobacco"
                       999 "LEGITIMATE SKIP" ;
label define IRHLT4    324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       510 "OTHER Inhalant, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRHLT5    221 "OTHER Tranquilizer, NOT SPECIFIED"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK1    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       208 "Centrax" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or crank)"
                       339 "Amphetamines (speed)" 409 "Tylenol with Codeine"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       509 "Correction fluids, degreasers, cleaning"
                       601 "LSD (acid, white lightning)" 603 "Mescaline"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK2    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed)" 348 "Crystal" 415 "Codeine"
                       418 "Methadone"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       807 "Alcohol" 813 "Cigarettes, Tobacco"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK3    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       339 "Amphetamines (speed)"
                       601 "LSD (acid, white lightning)"
                       607 "OTHER Hallucinogen NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK4    221 "OTHER Tranquilizer, NOT SPECIFID"
                       601 "LSD (acid, white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRNTK5    324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       999 "LEGITIMATE SKIP" ;
label define IRUPS1    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       208 "Centrax" 322 "Methamphetamine (speed or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       332 "Ephedrine, Caffeine, No-Doz, Vivarin"
                       339 "Amphetamines (speed)" 418 "Methadone"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 811 "Muscle relaxers"
                       813 "Cigarettes, Tobacco" 815 "Coffee" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRUPS2    201 "Valium" 312 "Ionamin"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco"
                       999 "LEGITIMATE SKIP" ;
label define IRUPS3    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       315 "Voranil" 339 "Amphetamines (speed)" 702 "Heroin"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRUPS4    221 "OTHER Tranquilizer, NOT SPECIFIED" 702 "Heroin"
                       807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRUPS5    324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       999 "LEGITIMATE SKIP" ;
label define IRLSW1    201 "Valium" 322 "Methamphetamine (speed or crank)"
                       348 "Crystal" 420 "OTHER Analgesic, NOT SPECIFIED"
                       425 "Advil" 601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 613 "Duckweed"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 812 "Cigars" 813 "Cigarettes, Tobacco"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define IRLSW2    418 "Methadone" 803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol" 813 "Cigarettes, Tobacco"
                       999 "LEGITIMATE SKIP" ;
label define IRLSW3    339 "Amphetamines (speed)" 805 "Cocaine, Coke"
                       999 "LEGITIMATE SKIP" ;
label define IRLSW4    601 "LSD (acid, white lightning)" 803 "Marijuana"
                       807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRLSW5    999 "LEGITIMATE SKIP" ;
label define IRSSP1    201 "Valium" 307 "Tenuate" 318 "Ritalin"
                       322 "Methamphetamine (speed or crank)"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRSSP2    324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       418 "Methadone" 510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco"
                       999 "LEGITIMATE SKIP" ;
label define IRSSP3    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       339 "Amphetamines (speed)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRSSP4    221 "OTHER Tranquilizer, NOT SPECIFIED"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       803 "Marijuana" 807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRSSP5    324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       999 "LEGITIMATE SKIP" ;
label define IRCPE1    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium" 312 "Ionamin"
                       322 "Methamphetamine (speed or crank)"
                       339 "Amphetamines (speed)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRCPE2    315 "Voranil" 348 "Crystal"
                       601 "LSD (acid, white lightning)" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 999 "LEGITIMATE SKIP" ;
label define IRCPE3    339 "Amphetamines (speed)"
                       604 "Psilocybin (mushrooms)" 702 "Heroin"
                       805 "Cocaine, Coke" 999 "LEGITIMATE SKIP" ;
label define IRCPE4    702 "Heroin" 807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRCPE5    999 "LEGITIMATE SKIP" ;
label define IREMG1    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       339 "Amphetamines (speed)" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol" 813 "Cigarettes, Tobacco"
                       998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define IREMG2    803 "Marijuana" 805 "Cocaine, Coke"
                       999 "LEGITIMATE SKIP" ;
label define IREMG3    702 "Heroin" 805 "Cocaine, Coke" 999 "LEGITIMATE SKIP" ;
label define IREMG4    999 "LEGITIMATE SKIP" ;
label define IREMG5    999 "LEGITIMATE SKIP" ;
label define ANYPROB   0 "No" 1 "Yes" ;
label define TWOPROB   0 "No" 1 "Yes" ;
label define THREPROB  0 "No" 1 "Yes" ;
label define DEPCIG2   0 "No" 1 "Yes" ;
label define DEPALC2   0 "No" 1 "Yes" ;
label define DEPMRJ2   0 "No" 1 "Yes" ;
label define DEPCOC2   0 "No" 1 "Yes" ;
label define ARGCIG2   0 "No" 1 "Yes" ;
label define ARGALC2   0 "No" 1 "Yes" ;
label define ARGMRJ2   0 "No" 1 "Yes" ;
label define ARGCOC2   0 "No" 1 "Yes" ;
label define ALNCIG2   0 "No" 1 "Yes" ;
label define ALNALC2   0 "No" 1 "Yes" ;
label define ALNMRJ2   0 "No" 1 "Yes" ;
label define ALNCOC2   0 "No" 1 "Yes" ;
label define ANXCIG2   0 "No" 1 "Yes" ;
label define ANXALC2   0 "No" 1 "Yes" ;
label define ANXMRJ2   0 "No" 1 "Yes" ;
label define ANXCOC2   0 "No" 1 "Yes" ;
label define HLTCIG2   0 "No" 1 "Yes" ;
label define HLTALC2   0 "No" 1 "Yes" ;
label define HLTMRJ2   0 "No" 1 "Yes" ;
label define HLTCOC2   0 "No" 1 "Yes" ;
label define NTKCIG2   0 "No" 1 "Yes" ;
label define NTKALC2   0 "No" 1 "Yes" ;
label define NTKMRJ2   0 "No" 1 "Yes" ;
label define NTKCOC2   0 "No" 1 "Yes" ;
label define UPSCIG2   0 "No" 1 "Yes" ;
label define UPSALC2   0 "No" 1 "Yes" ;
label define UPSMRJ2   0 "No" 1 "Yes" ;
label define UPSCOC2   0 "No" 1 "Yes" ;
label define LSWCIG2   0 "No" 1 "Yes" ;
label define LSWALC2   0 "No" 1 "Yes" ;
label define LSWMRJ2   0 "No" 1 "Yes" ;
label define LSWCOC2   0 "No" 1 "Yes" ;
label define SSPCIG2   0 "No" 1 "Yes" ;
label define SSPALC2   0 "No" 1 "Yes" ;
label define SSPMRJ2   0 "No" 1 "Yes" ;
label define SSPCOC2   0 "No" 1 "Yes" ;
label define CPECIG2   0 "No" 1 "Yes" ;
label define CPEALC2   0 "No" 1 "Yes" ;
label define CPEMRJ2   0 "No" 1 "Yes" ;
label define CPECOC2   0 "No" 1 "Yes" ;
label define EMCIG2    0 "No" 1 "Yes" ;
label define EMALC2    0 "No" 1 "Yes" ;
label define EMMRJ2    0 "No" 1 "Yes" ;
label define EMCOC2    0 "No" 1 "Yes" ;
label define PRB1CIG   0 "No" 1 "Yes" ;
label define PRB1ALC   0 "No" 1 "Yes" ;
label define PRB1MRJ   0 "No" 1 "Yes" ;
label define PRB1COC   0 "No" 1 "Yes" ;
label define PRB2CIG   0 "No" 1 "Yes" ;
label define PRB2ALC   0 "No" 1 "Yes" ;
label define PRB2MRJ   0 "No" 1 "Yes" ;
label define PRB2COC   0 "No" 1 "Yes" ;
label define PRB3CIG   0 "No" 1 "Yes" ;
label define PRB3ALC   0 "No" 1 "Yes" ;
label define PRB3MRJ   0 "No" 1 "Yes" ;
label define PRB3COC   0 "No" 1 "Yes" ;
label define IRCDCIG   1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in pastyr"
                       99 "LEGITIMATE SKIP" ;
label define IRCDALC   1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in pastyr"
                       99 "LEGITIMATE SKIP" ;
label define IRCDMJ    1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in pastyr"
                       99 "LEGITIMATE SKIP" ;
label define IRCDCOC   1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in pastyr"
                       99 "LEGITIMATE SKIP" ;
label define IREFCIG   1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for same effect"
                       99 "LEGITIMATE SKIP" ;
label define IREFALC   1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for same effect"
                       99 "LEGITIMATE SKIP" ;
label define IREFMJ    1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for same effect"
                       99 "LEGITIMATE SKIP" ;
label define IREFCOC   1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for same effect"
                       99 "LEGITIMATE SKIP" ;
label define IRUDCIG   1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past year"
                       99 "LEGITIMATE SKIP" ;
label define IRUDALC   1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past year"
                       99 "LEGITIMATE SKIP" ;
label define IRUDMJ    1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past year"
                       99 "LEGITIMATE SKIP" ;
label define IRUDCOC   1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past year"
                       99 "LEGITIMATE SKIP" ;
label define IRDPCIG   1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug used pastyr"
                       99 "LEGITIMATE SKIP" ;
label define IRDPALC   1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug used pastyr"
                       99 "LEGITIMATE SKIP" ;
label define IRDPMJ    1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug used pastyr"
                       99 "LEGITIMATE SKIP" ;
label define IRDPCOC   1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug used pastyr"
                       99 "LEGITIMATE SKIP" ;
label define IRWSCIG   1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the pastyr"
                       99 "LEGITIMATE SKIP" ;
label define IRWSALC   1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the pastyr"
                       99 "LEGITIMATE SKIP" ;
label define IRWSMJ    1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the pastyr"
                       99 "LEGITIMATE SKIP" ;
label define IRWSCOC   1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the pastyr"
                       99 "LEGITIMATE SKIP" ;
label define ALCPROBS  0 "No" 1 "Yes" ;
label define MJPROBS   0 "No" 1 "Yes" ;
label define COCPROBS  0 "No" 1 "Yes" ;
label define CIGPROBS  0 "No" 1 "Yes" ;
label define IRALCAGG  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCARG  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCABS  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCHIG  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCJOB  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCMAT  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCREL  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCFRD  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCTOS  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCHOL  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCDRU  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCINT  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCREM  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCQUI  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCMOR  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCSHO  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCALO  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRALCBRK  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IRNOBOOZ  1 "No use of alcohol in the past year"
                       2 "Used alcohol in the past year" ;
label define ANYALC    0 "No" 1 "Yes" ;
label define THREALC   0 "No" 1 "Yes" ;
label define DRUNKYR2  0 "Unknown" 1 "Drunk more than twice a month"
                       2 "Drunk twice a month or less"
                       3 "Never drunk in past year" ;
label define IRAS13    1 "Never used any of the substances listed"
                       2 "Used one or more of the listed substance" ;
label define AVCIG3    0 "None, never, < pack a day"
                       1 "Currently smoke a pack or more per day" ;
label define IRNODRUG  1 "No use of cig/alc/other drugs past year"
                       2 "Use of cig/alc/other drugs past year" ;
label define ALCONLYL  0 "No" 1 "Yes" ;
label define ALCONLYY  0 "No" 1 "Yes" ;
label define ALCONLYM  0 "No" 1 "Yes" ;
label define ILLONLYL  0 "No" 1 "Yes" ;
label define ILLONLYY  0 "No" 1 "Yes" ;
label define ILLONLYM  0 "No" 1 "Yes" ;
label define MRJONLYL  0 "No" 1 "Yes" ;
label define MRJONLYY  0 "No" 1 "Yes" ;
label define MRJONLYM  0 "No" 1 "Yes" ;
label define PSYONLYL  0 "No" 1 "Yes" ;
label define PSYONLYY  0 "No" 1 "Yes" ;
label define PSYONLYM  0 "No" 1 "Yes" ;
label define OTHONLYL  0 "No" 1 "Yes" ;
label define OTHONLYY  0 "No" 1 "Yes" ;
label define OTHONLYM  0 "No" 1 "Yes" ;
label define ALCILLL   0 "No" 1 "Yes" ;
label define ALCILLY   0 "No" 1 "Yes" ;
label define ALCILLM   0 "No" 1 "Yes" ;
label define ALCMRJL   0 "No" 1 "Yes" ;
label define ALCMRJY   0 "No" 1 "Yes" ;
label define ALCMRJM   0 "No" 1 "Yes" ;
label define ALCPSYL   0 "No" 1 "Yes" ;
label define ALCPSYY   0 "No" 1 "Yes" ;
label define ALCPSYM   0 "No" 1 "Yes" ;
label define ALCOTHL   0 "No" 1 "Yes" ;
label define ALCOTHY   0 "No" 1 "Yes" ;
label define ALCOTHM   0 "No" 1 "Yes" ;
label define SUB1LIF   0 "No" 1 "Yes" ;
label define SUB2LIF   0 "No" 1 "Yes" ;
label define SUB3LIF   0 "No" 1 "Yes" ;
label define SUB1YR    0 "No" 1 "Yes" ;
label define SUB2YR    0 "No" 1 "Yes" ;
label define SUB3YR    0 "No" 1 "Yes" ;
label define SUB1MON   0 "No" 1 "Yes" ;
label define SUB2MON   0 "No" 1 "Yes" ;
label define SUB3MON   0 "No" 1 "Yes" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CIGTRY = . if (CIGTRY >= 91 )
replace CIG5PK = . if (CIG5PK >= 91 )
replace CIGREC = . if (CIGREC >= 91 )
replace AVCIG = . if (AVCIG >= 91 )
replace CIGTIME = . if (CIGTIME >= 91 )
replace CIGINT = . if (CIGINT >= 91 )
replace CIGAGE = . if (CIGAGE >= 91 )
replace CIGYRS = . if (CIGYRS >= 91 )
replace PACKS = . if (PACKS >= 91 )
replace SNUFREC = . if (SNUFREC >= 91 )
replace SNUFFREQ = . if (SNUFFREQ >= 91 )
replace ALCTRY = . if (ALCTRY >= 91 )
replace ALCREC = . if (ALCREC >= 91 )
replace ALCPREF = . if (ALCPREF >= 91 )
replace ALCDAYS = . if (ALCDAYS >= 91 )
replace NODR30A = . if (NODR30A >= 91 )
replace MODR30A = . if (MODR30A >= 91 )
replace MODR30DY = . if (MODR30DY >= 91 )
replace DR5DAY = . if (DR5DAY >= 91 )
replace ALCAGE = . if (ALCAGE >= 91 )
replace ALCPAT = . if (ALCPAT >= 91 )
replace DRUNKYR = . if (DRUNKYR >= 91 )
replace ALCSED = . if (ALCSED >= 91 )
replace ALCTRAN = . if (ALCTRAN >= 91 )
replace ALCSTM = . if (ALCSTM >= 91 )
replace ALCANAL = . if (ALCANAL >= 91 )
replace ALCMJ = . if (ALCMJ >= 91 )
replace ALCINH = . if (ALCINH >= 91 )
replace ALCCOC = . if (ALCCOC >= 91 )
replace ALCHAL = . if (ALCHAL >= 91 )
replace ALCOPT = . if (ALCOPT >= 91 )
replace ALCNONE = . if (ALCNONE >= 91 )
replace NOSEDAT = . if (NOSEDAT >= 91 )
replace BUTISOL = . if (BUTISOL >= 91 )
replace BUTICAPS = . if (BUTICAPS >= 91 )
replace AMYTAL = . if (AMYTAL >= 91 )
replace MEBARAL = . if (MEBARAL >= 91 )
replace PLACIDYL = . if (PLACIDYL >= 91 )
replace DORIDEN = . if (DORIDEN >= 91 )
replace NOLUDAR = . if (NOLUDAR >= 91 )
replace NEMBUTAL = . if (NEMBUTAL >= 91 )
replace SECONAL = . if (SECONAL >= 91 )
replace TUINAL = . if (TUINAL >= 91 )
replace DALMANE = . if (DALMANE >= 91 )
replace RESTORIL = . if (RESTORIL >= 91 )
replace HALCION = . if (HALCION >= 91 )
replace AMOBARB = . if (AMOBARB >= 91 )
replace PHENOBAR = . if (PHENOBAR >= 91 )
replace METHAQ = . if (METHAQ >= 91 )
replace CHHYD = . if (CHHYD >= 91 )
replace PENTOB = . if (PENTOB >= 91 )
replace SECOB = . if (SECOB >= 91 )
replace SEDNEWA = . if (SEDNEWA >= 991 )
replace SEDNEWB = . if (SEDNEWB >= 991 )
replace SEDNOSP = . if (SEDNOSP >= 91 )
replace SEDDKNAM = . if (SEDDKNAM >= 91 )
replace SEDAGE = . if (SEDAGE >= 91 )
replace SEDTOT = . if (SEDTOT >= 91 )
replace SEDREC = . if (SEDREC >= 91 )
replace SEDALC = . if (SEDALC >= 91 )
replace SEDTR = . if (SEDTR >= 91 )
replace SEDST = . if (SEDST >= 91 )
replace SEDAN = . if (SEDAN >= 91 )
replace SEDMJ = . if (SEDMJ >= 91 )
replace SEDINH = . if (SEDINH >= 91 )
replace SEDCOC = . if (SEDCOC >= 91 )
replace SEDHAL = . if (SEDHAL >= 91 )
replace SEDOPT = . if (SEDOPT >= 91 )
replace SEDNONE = . if (SEDNONE >= 91 )
replace AS3READ = . if (AS3READ >= 91 )
replace NOTRANQ = . if (NOTRANQ >= 91 )
replace VALIUM = . if (VALIUM >= 91 )
replace LIBRIUM = . if (LIBRIUM >= 91 )
replace LIMBTROL = . if (LIMBTROL >= 91 )
replace MENRIUM = . if (MENRIUM >= 91 )
replace SERAX = . if (SERAX >= 91 )
replace TRANXENE = . if (TRANXENE >= 91 )
replace ATIVAN = . if (ATIVAN >= 91 )
replace CENTRAX = . if (CENTRAX >= 91 )
replace XANAX = . if (XANAX >= 91 )
replace PAXIPAM = . if (PAXIPAM >= 91 )
replace BUSPAR = . if (BUSPAR >= 91 )
replace MILTOWN = . if (MILTOWN >= 91 )
replace EQUANIL = . if (EQUANIL >= 91 )
replace DEPROL = . if (DEPROL >= 91 )
replace VISTAR = . if (VISTAR >= 91 )
replace ATARAX = . if (ATARAX >= 91 )
replace DURRAX = . if (DURRAX >= 91 )
replace DIAZEPAM = . if (DIAZEPAM >= 91 )
replace SKLY = . if (SKLY >= 91 )
replace MEPROB = . if (MEPROB >= 91 )
replace TRNEWA = . if (TRNEWA >= 991 )
replace TRNOSP = . if (TRNOSP >= 91 )
replace TRDKNAM = . if (TRDKNAM >= 91 )
replace TRANAGE = . if (TRANAGE >= 91 )
replace TRANTOT = . if (TRANTOT >= 91 )
replace TRANREC = . if (TRANREC >= 91 )
replace TRALC = . if (TRALC >= 91 )
replace TRSED = . if (TRSED >= 91 )
replace TRSTM = . if (TRSTM >= 91 )
replace TRANAL = . if (TRANAL >= 91 )
replace TRMJ = . if (TRMJ >= 91 )
replace TRINH = . if (TRINH >= 91 )
replace TRCOC = . if (TRCOC >= 91 )
replace TRHAL = . if (TRHAL >= 91 )
replace TROPT = . if (TROPT >= 91 )
replace TRNONE = . if (TRNONE >= 91 )
replace AS4READ = . if (AS4READ >= 91 )
replace NOSTIMS = . if (NOSTIMS >= 91 )
replace DEXED = . if (DEXED >= 91 )
replace DEXAMYL = . if (DEXAMYL >= 91 )
replace ESKAT = . if (ESKAT >= 91 )
replace BENZ = . if (BENZ >= 91 )
replace BIPHET = . if (BIPHET >= 91 )
replace DESOXYN = . if (DESOXYN >= 91 )
replace TENUATE = . if (TENUATE >= 91 )
replace TEPANIL = . if (TEPANIL >= 91 )
replace DIDREX = . if (DIDREX >= 91 )
replace PLEGINE = . if (PLEGINE >= 91 )
replace PRELUDIN = . if (PRELUDIN >= 91 )
replace IONAMIN = . if (IONAMIN >= 91 )
replace FASTIN = . if (FASTIN >= 91 )
replace PONDIMIN = . if (PONDIMIN >= 91 )
replace VORANIL = . if (VORANIL >= 91 )
replace SANOREX = . if (SANOREX >= 91 )
replace MAZANOR = . if (MAZANOR >= 91 )
replace RITALIN = . if (RITALIN >= 91 )
replace CYLERT = . if (CYLERT >= 91 )
replace DETAMP = . if (DETAMP >= 91 )
replace METHI = . if (METHI >= 91 )
replace METHAMP = . if (METHAMP >= 91 )
replace OBLA = . if (OBLA >= 91 )
replace STIMNEWA = . if (STIMNEWA >= 991 )
replace STIMNEWB = . if (STIMNEWB >= 991 )
replace STIMNEWC = . if (STIMNEWC >= 991 )
replace STIMNEWD = . if (STIMNEWD >= 991 )
replace STIMNOSP = . if (STIMNOSP >= 91 )
replace STMDKNAM = . if (STMDKNAM >= 91 )
replace STIMAGE = . if (STIMAGE >= 91 )
replace STIMTOT = . if (STIMTOT >= 91 )
replace STIMREC = . if (STIMREC >= 91 )
replace STALC = . if (STALC >= 91 )
replace STSED = . if (STSED >= 91 )
replace STTRAN = . if (STTRAN >= 91 )
replace STANAL = . if (STANAL >= 91 )
replace STMJ = . if (STMJ >= 91 )
replace STINH = . if (STINH >= 91 )
replace STCOC = . if (STCOC >= 91 )
replace STHAL = . if (STHAL >= 91 )
replace STOPT = . if (STOPT >= 91 )
replace STNONE = . if (STNONE >= 91 )
replace STNEEDLE = . if (STNEEDLE >= 91 )
replace STNDLREC = . if (STNDLREC >= 91 )
replace AS5READ = . if (AS5READ >= 91 )
replace ANALNONE = . if (ANALNONE >= 91 )
replace DARVON = . if (DARVON >= 91 )
replace DOLENE = . if (DOLENE >= 91 )
replace SK65A = . if (SK65A >= 91 )
replace WYGESIC = . if (WYGESIC >= 91 )
replace LEVODRO = . if (LEVODRO >= 91 )
replace PERCODAN = . if (PERCODAN >= 91 )
replace DEMEROL = . if (DEMEROL >= 91 )
replace DILAUD = . if (DILAUD >= 91 )
replace TYLCOD = . if (TYLCOD >= 91 )
replace PHENCOD = . if (PHENCOD >= 91 )
replace TALWIN = . if (TALWIN >= 91 )
replace TALWINNX = . if (TALWINNX >= 91 )
replace TALACEN = . if (TALACEN >= 91 )
replace PROPOXY = . if (PROPOXY >= 91 )
replace CODEINE = . if (CODEINE >= 91 )
replace ANILERID = . if (ANILERID >= 91 )
replace MORPHINE = . if (MORPHINE >= 91 )
replace METHDON = . if (METHDON >= 91 )
replace STADOL = . if (STADOL >= 91 )
replace ANALNEWA = . if (ANALNEWA >= 991 )
replace ANALNEWB = . if (ANALNEWB >= 991 )
replace ANLNOSP = . if (ANLNOSP >= 91 )
replace ANLDKNAM = . if (ANLDKNAM >= 91 )
replace ANALAGE = . if (ANALAGE >= 91 )
replace ANALTOT = . if (ANALTOT >= 91 )
replace ANALREC = . if (ANALREC >= 91 )
replace ANLALC = . if (ANLALC >= 91 )
replace ANLSED = . if (ANLSED >= 91 )
replace ANLTRAN = . if (ANLTRAN >= 91 )
replace ANLSTM = . if (ANLSTM >= 91 )
replace ANLMJ = . if (ANLMJ >= 91 )
replace ANLINH = . if (ANLINH >= 91 )
replace ANLCOC = . if (ANLCOC >= 91 )
replace ANLHAL = . if (ANLHAL >= 91 )
replace ANLOPT = . if (ANLOPT >= 91 )
replace ANLNONE = . if (ANLNONE >= 91 )
replace MJOPP = . if (MJOPP >= 91 )
replace MJAGE = . if (MJAGE >= 91 )
replace MJTOT = . if (MJTOT >= 91 )
replace MJREC = . if (MJREC >= 91 )
replace MJDAY30A = . if (MJDAY30A >= 91 )
replace MJAV30A = . if (MJAV30A >= 91 )
replace MJAMT30A = . if (MJAMT30A >= 91 )
replace MJALC30A = . if (MJALC30A >= 6 )
replace MJYRFREQ = . if (MJYRFREQ >= 91 )
replace MJALC = . if (MJALC >= 91 )
replace MJSED = . if (MJSED >= 91 )
replace MJTRAN = . if (MJTRAN >= 91 )
replace MJSTM = . if (MJSTM >= 91 )
replace MJANAL = . if (MJANAL >= 91 )
replace MJINH = . if (MJINH >= 91 )
replace MJCOC = . if (MJCOC >= 91 )
replace MJHAL = . if (MJHAL >= 91 )
replace MJOPT = . if (MJOPT >= 91 )
replace MJNONE = . if (MJNONE >= 91 )
replace AS7READ = . if (AS7READ >= 91 )
replace INHAGE = . if (INHAGE >= 91 )
replace GAS = . if (GAS >= 91 )
replace SPPAINT = . if (SPPAINT >= 91 )
replace AEROS = . if (AEROS >= 91 )
replace GLUE = . if (GLUE >= 91 )
replace SOLVENT = . if (SOLVENT >= 91 )
replace AMYLNIT = . if (AMYLNIT >= 91 )
replace ETHER = . if (ETHER >= 91 )
replace NITOXID = . if (NITOXID >= 91 )
replace CLEFLU = . if (CLEFLU >= 91 )
replace INHNEWA = . if (INHNEWA >= 991 )
replace INHNEWB = . if (INHNEWB >= 991 )
replace INHNOSP = . if (INHNOSP >= 91 )
replace INHTOT = . if (INHTOT >= 91 )
replace GAS30A = . if (GAS30A >= 91 )
replace SPPAN30A = . if (SPPAN30A >= 91 )
replace AEROS30A = . if (AEROS30A >= 91 )
replace GLUE30A = . if (GLUE30A >= 91 )
replace SOLVN30A = . if (SOLVN30A >= 91 )
replace AMLNT30A = . if (AMLNT30A >= 91 )
replace ETHER30A = . if (ETHER30A >= 91 )
replace NOX30A = . if (NOX30A >= 91 )
replace CLFL30A = . if (CLFL30A >= 91 )
replace INNEW30A = . if (INNEW30A >= 991 )
replace INNEW30B = . if (INNEW30B >= 991 )
replace IN30NOSP = . if (IN30NOSP >= 91 )
replace INH30NO = . if (INH30NO >= 91 )
replace INHDY30A = . if (INHDY30A >= 91 )
replace INHREC = . if (INHREC >= 91 )
replace INHEFF = . if (INHEFF >= 91 )
replace INHPO = . if (INHPO >= 91 )
replace INHQNC1 = . if (INHQNC1 >= 91 )
replace INHQNC2 = . if (INHQNC2 >= 91 )
replace INHQNC3 = . if (INHQNC3 >= 91 )
replace INHQNC4 = . if (INHQNC4 >= 91 )
replace INHQNC5 = . if (INHQNC5 >= 91 )
replace INHQNC6 = . if (INHQNC6 >= 91 )
replace INHQNC7 = . if (INHQNC7 >= 91 )
replace INHQNC8 = . if (INHQNC8 >= 91 )
replace INHQNC9 = . if (INHQNC9 >= 91 )
replace INHANSY = . if (INHANSY >= 91 )
replace COCOPP = . if (COCOPP >= 91 )
replace COCAGE = . if (COCAGE >= 91 )
replace COCTOT = . if (COCTOT >= 91 )
replace COCREC = . if (COCREC >= 91 )
replace COCUS30A = . if (COCUS30A >= 91 )
replace COC30ALC = . if (COC30ALC >= 91 )
replace COCYRFRQ = . if (COCYRFRQ >= 91 )
replace COCALC = . if (COCALC >= 91 )
replace COCSED = . if (COCSED >= 91 )
replace COCTRAN = . if (COCTRAN >= 91 )
replace COCSTM = . if (COCSTM >= 91 )
replace COCANAL = . if (COCANAL >= 91 )
replace COCINH = . if (COCINH >= 91 )
replace COCMJ = . if (COCMJ >= 91 )
replace COCHAL = . if (COCHAL >= 91 )
replace COCOPT = . if (COCOPT >= 91 )
replace COCNONE = . if (COCNONE >= 91 )
replace COCSNIFF = . if (COCSNIFF >= 91 )
replace COCSWAL = . if (COCSWAL >= 91 )
replace COCIV = . if (COCIV >= 91 )
replace FREEBASE = . if (FREEBASE >= 91 )
replace COCNEWA = . if (COCNEWA >= 91 )
replace COCNOSP = . if (COCNOSP >= 91 )
replace CONDLREC = . if (CONDLREC >= 91 )
replace CRAKREC = . if (CRAKREC >= 91 )
replace CRKAM30A = . if (CRKAM30A >= 991 )
replace CRAKBUCK = . if (CRAKBUCK >= 9993 )
replace COCAM30A = . if (COCAM30A >= 91 )
replace COCBUCK = . if (COCBUCK >= 9991 )
replace AS9READ = . if (AS9READ >= 91 )
replace LSD = . if (LSD >= 91 )
replace PEYOTE = . if (PEYOTE >= 91 )
replace MESC = . if (MESC >= 91 )
replace PSILCY = . if (PSILCY >= 91 )
replace PCP = . if (PCP >= 91 )
replace ECSTASY = . if (ECSTASY >= 91 )
replace HALNEWA = . if (HALNEWA >= 991 )
replace HALNOSP = . if (HALNOSP >= 91 )
replace HALLOPP = . if (HALLOPP >= 91 )
replace HALLAGE = . if (HALLAGE >= 91 )
replace HALLTOT = . if (HALLTOT >= 91 )
replace HALLREC = . if (HALLREC >= 91 )
replace HAL30USE = . if (HAL30USE >= 91 )
replace PCPREC = . if (PCPREC >= 91 )
replace PCPFLASH = . if (PCPFLASH >= 91 )
replace PCPSENSE = . if (PCPSENSE >= 91 )
replace PCPFEELV = . if (PCPFEELV >= 91 )
replace PCPACTV = . if (PCPACTV >= 91 )
replace PCPNEWA = . if (PCPNEWA >= 91 )
replace PCPNEWB = . if (PCPNEWB >= 91 )
replace PCPNEWC = . if (PCPNEWC >= 91 )
replace PCPNOSP = . if (PCPNOSP >= 91 )
replace PCPNORCT = . if (PCPNORCT >= 91 )
replace HALLQCL = . if (HALLQCL >= 91 )
replace AS10READ = . if (AS10READ >= 91 )
replace HEROPP = . if (HEROPP >= 91 )
replace HERAGE = . if (HERAGE >= 91 )
replace HERTOT = . if (HERTOT >= 91 )
replace HERREC = . if (HERREC >= 91 )
replace HER30USE = . if (HER30USE >= 91 )
replace HERNEEDL = . if (HERNEEDL >= 91 )
replace HRNDLREC = . if (HRNDLREC >= 91 )
replace AS11READ = . if (AS11READ >= 91 )
replace NODRUGS = . if (NODRUGS >= 91 )
replace CDCIG = . if (CDCIG >= 13 )
replace CDALC = . if (CDALC >= 13 )
replace CDSED = . if (CDSED >= 13 )
replace CDTRAN = . if (CDTRAN >= 13 )
replace CDSTM = . if (CDSTM >= 13 )
replace CDANAL = . if (CDANAL >= 13 )
replace CDMJ = . if (CDMJ >= 13 )
replace CDINH = . if (CDINH >= 13 )
replace CDCOC = . if (CDCOC >= 13 )
replace CDHALL = . if (CDHALL >= 13 )
replace CDHER = . if (CDHER >= 13 )
replace CDOTHOP = . if (CDOTHOP >= 13 )
replace CDNONE = . if (CDNONE >= 91 )
replace EFFCIG = . if (EFFCIG >= 13 )
replace EFFALC = . if (EFFALC >= 13 )
replace EFFSED = . if (EFFSED >= 13 )
replace EFFTRAN = . if (EFFTRAN >= 13 )
replace EFFSTM = . if (EFFSTM >= 13 )
replace EFFANAL = . if (EFFANAL >= 13 )
replace EFFMJ = . if (EFFMJ >= 13 )
replace EFFINH = . if (EFFINH >= 13 )
replace EFFCOC = . if (EFFCOC >= 13 )
replace EFFHALL = . if (EFFHALL >= 13 )
replace EFFHER = . if (EFFHER >= 13 )
replace EFFOTHOP = . if (EFFOTHOP >= 13 )
replace EFFNONE = . if (EFFNONE >= 91 )
replace UDAYCIG = . if (UDAYCIG >= 13 )
replace UDAYALC = . if (UDAYALC >= 13 )
replace UDAYSED = . if (UDAYSED >= 13 )
replace UDAYTRAN = . if (UDAYTRAN >= 13 )
replace UDAYSTM = . if (UDAYSTM >= 13 )
replace UDAYANAL = . if (UDAYANAL >= 13 )
replace UDAYMJ = . if (UDAYMJ >= 13 )
replace UDAYINH = . if (UDAYINH >= 13 )
replace UDAYCOC = . if (UDAYCOC >= 13 )
replace UDAYHALL = . if (UDAYHALL >= 13 )
replace UDAYHER = . if (UDAYHER >= 13 )
replace UDAYOTH = . if (UDAYOTH >= 13 )
replace UDAYNONE = . if (UDAYNONE >= 91 )
replace DEPCIG = . if (DEPCIG >= 13 )
replace DEPALC = . if (DEPALC >= 13 )
replace DEPSED = . if (DEPSED >= 13 )
replace DEPTRAN = . if (DEPTRAN >= 13 )
replace DEPSTM = . if (DEPSTM >= 13 )
replace DEPANAL = . if (DEPANAL >= 13 )
replace DEPMJ = . if (DEPMJ >= 13 )
replace DEPINH = . if (DEPINH >= 13 )
replace DEPCOC = . if (DEPCOC >= 13 )
replace DEPHALL = . if (DEPHALL >= 13 )
replace DEPHER = . if (DEPHER >= 13 )
replace DEPOTHOP = . if (DEPOTHOP >= 13 )
replace DEPNONE = . if (DEPNONE >= 91 )
replace WSCIG = . if (WSCIG >= 13 )
replace WSALC = . if (WSALC >= 13 )
replace WSSED = . if (WSSED >= 13 )
replace WSTRAN = . if (WSTRAN >= 13 )
replace WSSTM = . if (WSSTM >= 13 )
replace WSANAL = . if (WSANAL >= 13 )
replace WSMJ = . if (WSMJ >= 13 )
replace WSINH = . if (WSINH >= 13 )
replace WSCOC = . if (WSCOC >= 13 )
replace WSHALL = . if (WSHALL >= 13 )
replace WSHER = . if (WSHER >= 13 )
replace WSOTHOP = . if (WSOTHOP >= 13 )
replace WSNONE = . if (WSNONE >= 91 )
replace SHRNDLMO = . if (SHRNDLMO >= 91 )
replace NRSHRNDL = . if (NRSHRNDL >= 91 )
replace CLEANNDL = . if (CLEANNDL >= 91 )
replace SHRWMALE = . if (SHRWMALE >= 91 )
replace SHRWSEXP = . if (SHRWSEXP >= 91 )
replace SHRWRACE = . if (SHRWRACE >= 91 )
replace RSNNOSHR = . if (RSNNOSHR >= 91 )
replace NOBOOZYR = . if (NOBOOZYR >= 91 )
replace ALCAGGR = . if (ALCAGGR >= 91 )
replace ALCARGUM = . if (ALCARGUM >= 91 )
replace ALCABSNT = . if (ALCABSNT >= 91 )
replace ALCHIGH = . if (ALCHIGH >= 91 )
replace ALCJOB = . if (ALCJOB >= 91 )
replace ALCMATCD = . if (ALCMATCD >= 91 )
replace ALCRELCD = . if (ALCRELCD >= 91 )
replace ALCFRDCD = . if (ALCFRDCD >= 91 )
replace ALCTOSS = . if (ALCTOSS >= 91 )
replace ALCHOLIC = . if (ALCHOLIC >= 91 )
replace ALCDRUNK = . if (ALCDRUNK >= 91 )
replace ALCINTOX = . if (ALCINTOX >= 91 )
replace ALCREM = . if (ALCREM >= 91 )
replace ALCQUICK = . if (ALCQUICK >= 91 )
replace ALCMORN = . if (ALCMORN >= 91 )
replace ALCSHOOK = . if (ALCSHOOK >= 91 )
replace ALCALONE = . if (ALCALONE >= 91 )
replace ALCBRKPM = . if (ALCBRKPM >= 91 )
replace AS13NONE = . if (AS13NONE >= 91 )
replace DRDEPRSS = . if (DRDEPRSS >= 91 )
replace DEPDRG1A = . if (DEPDRG1A >= 991 )
replace DEPDRG2A = . if (DEPDRG2A >= 991 )
replace DEPDRG3A = . if (DEPDRG3A >= 991 )
replace DEPDRG4A = . if (DEPDRG4A >= 991 )
replace DEPDRG5A = . if (DEPDRG5A >= 991 )
replace DRARGUM = . if (DRARGUM >= 91 )
replace ARGDRG1A = . if (ARGDRG1A >= 991 )
replace ARGDRG2A = . if (ARGDRG2A >= 991 )
replace ARGDRG3A = . if (ARGDRG3A >= 991 )
replace ARGDRG4A = . if (ARGDRG4A >= 991 )
replace ARGDRG5A = . if (ARGDRG5A >= 991 )
replace DRALONE = . if (DRALONE >= 91 )
replace ALNDRG1A = . if (ALNDRG1A >= 991 )
replace ALNDRG2A = . if (ALNDRG2A >= 991 )
replace ALNDRG3A = . if (ALNDRG3A >= 991 )
replace ALNDRG4A = . if (ALNDRG4A >= 991 )
replace ALNDRG5A = . if (ALNDRG5A >= 991 )
replace DRANX = . if (DRANX >= 91 )
replace ANXDRG1A = . if (ANXDRG1A >= 991 )
replace ANXDRG2A = . if (ANXDRG2A >= 991 )
replace ANXDRG3A = . if (ANXDRG3A >= 991 )
replace ANXDRG4A = . if (ANXDRG4A >= 991 )
replace ANXDRG5A = . if (ANXDRG5A >= 991 )
replace DRHEALTH = . if (DRHEALTH >= 91 )
replace HLTDRG1A = . if (HLTDRG1A >= 991 )
replace HLTDRG2A = . if (HLTDRG2A >= 991 )
replace HLTDRG3A = . if (HLTDRG3A >= 991 )
replace HLTDRG4A = . if (HLTDRG4A >= 991 )
replace HLTDRG5A = . if (HLTDRG5A >= 991 )
replace DRNTHINK = . if (DRNTHINK >= 91 )
replace NTKDRG1A = . if (NTKDRG1A >= 991 )
replace NTKDRG2A = . if (NTKDRG2A >= 991 )
replace NTKDRG3A = . if (NTKDRG3A >= 991 )
replace NTKDRG4A = . if (NTKDRG4A >= 991 )
replace NTKDRG5A = . if (NTKDRG5A >= 991 )
replace DRUPSET = . if (DRUPSET >= 91 )
replace UPSDRG1A = . if (UPSDRG1A >= 991 )
replace UPSDRG2A = . if (UPSDRG2A >= 991 )
replace UPSDRG3A = . if (UPSDRG3A >= 991 )
replace UPSDRG4A = . if (UPSDRG4A >= 991 )
replace UPSDRG5A = . if (UPSDRG5A >= 991 )
replace DRLSWORK = . if (DRLSWORK >= 91 )
replace LSWDRG1A = . if (LSWDRG1A >= 991 )
replace LSWDRG2A = . if (LSWDRG2A >= 991 )
replace LSWDRG3A = . if (LSWDRG3A >= 991 )
replace LSWDRG4A = . if (LSWDRG4A >= 991 )
replace LSWDRG5A = . if (LSWDRG5A >= 991 )
replace DRSUSPIC = . if (DRSUSPIC >= 91 )
replace SSPDRG1A = . if (SSPDRG1A >= 991 )
replace SSPDRG2A = . if (SSPDRG2A >= 991 )
replace SSPDRG3A = . if (SSPDRG3A >= 991 )
replace SSPDRG4A = . if (SSPDRG4A >= 991 )
replace SSPDRG5A = . if (SSPDRG5A >= 991 )
replace DRCOPE = . if (DRCOPE >= 91 )
replace CPEDRG1A = . if (CPEDRG1A >= 991 )
replace CPEDRG2A = . if (CPEDRG2A >= 991 )
replace CPEDRG3A = . if (CPEDRG3A >= 991 )
replace CPEDRG4A = . if (CPEDRG4A >= 991 )
replace CPEDRG5A = . if (CPEDRG5A >= 991 )
replace DREMGMED = . if (DREMGMED >= 91 )
replace EMDRG1A = . if (EMDRG1A >= 991 )
replace EMDRG2A = . if (EMDRG2A >= 991 )
replace EMDRG3A = . if (EMDRG3A >= 991 )
replace EMDRG4A = . if (EMDRG4A >= 991 )
replace EMDRG5A = . if (EMDRG5A >= 991 )
replace RSKPKCIG = . if (RSKPKCIG >= 91 )
replace RSKMJOCC = . if (RSKMJOCC >= 91 )
replace RSKMJREG = . if (RSKMJREG >= 91 )
replace RKTRYPCP = . if (RKTRYPCP >= 91 )
replace RKPCPREG = . if (RKPCPREG >= 91 )
replace RKTRYHER = . if (RKTRYHER >= 91 )
replace RKHERREG = . if (RKHERREG >= 91 )
replace RKTRYCOC = . if (RKTRYCOC >= 91 )
replace RKCOCOCC = . if (RKCOCOCC >= 91 )
replace RKCOCREG = . if (RKCOCREG >= 91 )
replace RKCRKOCC = . if (RKCRKOCC >= 91 )
replace RK2DRINK = . if (RK2DRINK >= 91 )
replace RK5DRINK = . if (RK5DRINK >= 91 )
replace RSKBINGE = . if (RSKBINGE >= 91 )
replace HIGHBP = . if (HIGHBP >= 91 )
replace BPMED = . if (BPMED >= 91 )
replace WALKPAIN = . if (WALKPAIN >= 91 )
replace TIMEPAIN = . if (TIMEPAIN >= 91 )
replace UPSHOR = . if (UPSHOR >= 91 )
replace ASTHMA = . if (ASTHMA >= 91 )
replace TRPSYCH = . if (TRPSYCH >= 91 )
replace HEART = . if (HEART >= 91 )
replace FLU = . if (FLU >= 91 )
replace ALLERG = . if (ALLERG >= 91 )
replace HOSPYR = . if (HOSPYR >= 91 )
replace SOREYR = . if (SOREYR >= 91 )
replace RUNNYYR = . if (RUNNYYR >= 91 )
replace COUGHYR = . if (COUGHYR >= 91 )
replace PHLEGMYR = . if (PHLEGMYR >= 91 )
replace HEALTHYR = . if (HEALTHYR >= 91 )
replace MARITAL = . if (MARITAL >= 91 )
replace NOMARR = . if (NOMARR >= 91 )
replace WORKSTAT = . if (WORKSTAT >= 91 )
replace PAYMO = . if (PAYMO >= 91 )
replace PAYYR = . if (PAYYR >= 91 )
replace NO5JOB = . if (NO5JOB >= 91 )
replace WORKDAYS = . if (WORKDAYS >= 91 )
replace WORKBLAH = . if (WORKBLAH >= 91 )
replace CWE = . if (CWE >= 91 )
replace FULLPART = . if (FULLPART >= 91 )
replace EDUC = . if (EDUC >= 91 )
replace ENROLLD = . if (ENROLLD >= 91 )
replace SCHPLANS = . if (SCHPLANS >= 91 )
replace STUDENT = . if (STUDENT >= 91 )
replace SCHDAYS = . if (SCHDAYS >= 91 )
replace SKIPPED = . if (SKIPPED >= 91 )
replace MILES = . if (MILES >= 99991 )
replace ACCID = . if (ACCID >= 91 )
replace NOCHILD = . if (NOCHILD >= 91 )
replace TOTPEOP = . if (TOTPEOP >= 91 )
replace MOTHER = . if (MOTHER >= 91 )
replace STEPMOM = . if (STEPMOM >= 91 )
replace FATHER = . if (FATHER >= 91 )
replace STEPDAD = . if (STEPDAD >= 91 )
replace SPOUSE = . if (SPOUSE >= 91 )
replace INLAW = . if (INLAW >= 91 )
replace OWNCHILD = . if (OWNCHILD >= 91 )
replace STEPCHLD = . if (STEPCHLD >= 91 )
replace BROSIS = . if (BROSIS >= 91 )
replace OTHREL = . if (OTHREL >= 91 )
replace FRIENDS = . if (FRIENDS >= 91 )
replace OTHERNON = . if (OTHERNON >= 91 )
replace SERVICE = . if (SERVICE >= 91 )
replace MILSTAT = . if (MILSTAT >= 91 )
replace MOVDAWAY = . if (MOVDAWAY >= 91 )
replace DORM = . if (DORM >= 91 )
replace MILBASE = . if (MILBASE >= 91 )
replace HOSP = . if (HOSP >= 91 )
replace TELNO = . if (TELNO >= 91 )
replace MOVES = . if (MOVES >= 91 )
replace INCOME = . if (INCOME >= 91 )
replace UNDINT = . if (UNDINT >= 91 )
replace COOPINT = . if (COOPINT >= 91 )
replace PRIVACY = . if (PRIVACY >= 91 )
replace PPRES = . if (PPRES >= 91 )
replace SPRES = . if (SPRES >= 91 )
replace PARPRES = . if (PARPRES >= 91 )
replace OARPRES = . if (OARPRES >= 91 )
replace OAPRES = . if (OAPRES >= 91 )
replace CPRES = . if (CPRES >= 91 )
replace OPRESSPA = . if (OPRESSPA >= 91 )
replace OPRESSPB = . if (OPRESSPB >= 91 )
replace OPRESNSP = . if (OPRESNSP >= 91 )
replace IRAGE = . if (IRAGE >= 91 )
replace IRHOGRP = . if (IRHOGRP >= 9 )
replace IRALCRC = . if (IRALCRC >= 9 )
replace IRMJRC = . if (IRMJRC >= 9 )
replace IRCOCRC = . if (IRCOCRC >= 9 )
replace IRSEDRC = . if (IRSEDRC >= 9 )
replace IRTRNRC = . if (IRTRNRC >= 9 )
replace IRSTMRC = . if (IRSTMRC >= 9 )
replace IRANLRC = . if (IRANLRC >= 9 )
replace IRCIGRC = . if (IRCIGRC >= 9 )
replace IROTBRC = . if (IROTBRC >= 9 )
replace IRINHRC = . if (IRINHRC >= 9 )
replace IRCRKRC = . if (IRCRKRC >= 9 )
replace IRHALRC = . if (IRHALRC >= 9 )
replace IRHERRC = . if (IRHERRC >= 9 )
replace IRPCPRC = . if (IRPCPRC >= 9 )
replace IRALCFQ = . if (IRALCFQ >= 9 )
replace IRMJFQ = . if (IRMJFQ >= 10 )
replace IRCOCFQ = . if (IRCOCFQ >= 9 )
replace NEEDLREC = . if (NEEDLREC >= 91 )
replace VESTR = . if (VESTR >= 91 )
replace CHAGE9 = . if (CHAGE9 >= 91 )
replace CHAGE10 = . if (CHAGE10 >= 91 )
replace CWEOCC2 = . if (CWEOCC2 >= 990 )
replace ROCCUP2 = . if (ROCCUP2 >= 990 )
replace BUSINES2 = . if (BUSINES2 >= 990 )
replace CWEBUS2 = . if (CWEBUS2 >= 990 )
replace IRDEP = . if (IRDEP >= 91 )
replace IRARG = . if (IRARG >= 91 )
replace IRALN = . if (IRALN >= 91 )
replace IRANX = . if (IRANX >= 91 )
replace IRHLT = . if (IRHLT >= 91 )
replace IRNTK = . if (IRNTK >= 91 )
replace IRUPS = . if (IRUPS >= 91 )
replace IRLSW = . if (IRLSW >= 91 )
replace IRSSP = . if (IRSSP >= 91 )
replace IRCPE = . if (IRCPE >= 91 )
replace IREMG = . if (IREMG >= 91 )
replace IRDEP1 = . if (IRDEP1 >= 991 )
replace IRDEP2 = . if (IRDEP2 >= 991 )
replace IRDEP3 = . if (IRDEP3 >= 991 )
replace IRDEP4 = . if (IRDEP4 >= 991 )
replace IRDEP5 = . if (IRDEP5 >= 991 )
replace IRARG1 = . if (IRARG1 >= 991 )
replace IRARG2 = . if (IRARG2 >= 991 )
replace IRARG3 = . if (IRARG3 >= 991 )
replace IRARG4 = . if (IRARG4 >= 991 )
replace IRARG5 = . if (IRARG5 >= 991 )
replace IRALN1 = . if (IRALN1 >= 991 )
replace IRALN2 = . if (IRALN2 >= 991 )
replace IRALN3 = . if (IRALN3 >= 991 )
replace IRALN4 = . if (IRALN4 >= 991 )
replace IRALN5 = . if (IRALN5 >= 991 )
replace IRANX1 = . if (IRANX1 >= 991 )
replace IRANX2 = . if (IRANX2 >= 991 )
replace IRANX3 = . if (IRANX3 >= 991 )
replace IRANX4 = . if (IRANX4 >= 991 )
replace IRANX5 = . if (IRANX5 >= 991 )
replace IRHLT1 = . if (IRHLT1 >= 991 )
replace IRHLT2 = . if (IRHLT2 >= 991 )
replace IRHLT3 = . if (IRHLT3 >= 991 )
replace IRHLT4 = . if (IRHLT4 >= 991 )
replace IRHLT5 = . if (IRHLT5 >= 991 )
replace IRNTK1 = . if (IRNTK1 >= 991 )
replace IRNTK2 = . if (IRNTK2 >= 991 )
replace IRNTK3 = . if (IRNTK3 >= 991 )
replace IRNTK4 = . if (IRNTK4 >= 991 )
replace IRNTK5 = . if (IRNTK5 >= 991 )
replace IRUPS1 = . if (IRUPS1 >= 991 )
replace IRUPS2 = . if (IRUPS2 >= 991 )
replace IRUPS3 = . if (IRUPS3 >= 991 )
replace IRUPS4 = . if (IRUPS4 >= 991 )
replace IRUPS5 = . if (IRUPS5 >= 991 )
replace IRLSW1 = . if (IRLSW1 >= 991 )
replace IRLSW2 = . if (IRLSW2 >= 991 )
replace IRLSW3 = . if (IRLSW3 >= 991 )
replace IRLSW4 = . if (IRLSW4 >= 991 )
replace IRLSW5 = . if (IRLSW5 >= 991 )
replace IRSSP1 = . if (IRSSP1 >= 991 )
replace IRSSP2 = . if (IRSSP2 >= 991 )
replace IRSSP3 = . if (IRSSP3 >= 991 )
replace IRSSP4 = . if (IRSSP4 >= 991 )
replace IRSSP5 = . if (IRSSP5 >= 991 )
replace IRCPE1 = . if (IRCPE1 >= 991 )
replace IRCPE2 = . if (IRCPE2 >= 991 )
replace IRCPE3 = . if (IRCPE3 >= 991 )
replace IRCPE4 = . if (IRCPE4 >= 991 )
replace IRCPE5 = . if (IRCPE5 >= 991 )
replace IREMG1 = . if (IREMG1 >= 991 )
replace IREMG2 = . if (IREMG2 >= 991 )
replace IREMG3 = . if (IREMG3 >= 991 )
replace IREMG4 = . if (IREMG4 >= 991 )
replace IREMG5 = . if (IREMG5 >= 991 )
replace IRCDCIG = . if (IRCDCIG >= 13 )
replace IRCDALC = . if (IRCDALC >= 13 )
replace IRCDMJ = . if (IRCDMJ >= 13 )
replace IRCDCOC = . if (IRCDCOC >= 13 )
replace IREFCIG = . if (IREFCIG >= 13 )
replace IREFALC = . if (IREFALC >= 13 )
replace IREFMJ = . if (IREFMJ >= 13 )
replace IREFCOC = . if (IREFCOC >= 13 )
replace IRUDCIG = . if (IRUDCIG >= 13 )
replace IRUDALC = . if (IRUDALC >= 13 )
replace IRUDMJ = . if (IRUDMJ >= 13 )
replace IRUDCOC = . if (IRUDCOC >= 13 )
replace IRDPCIG = . if (IRDPCIG >= 13 )
replace IRDPALC = . if (IRDPALC >= 13 )
replace IRDPMJ = . if (IRDPMJ >= 13 )
replace IRDPCOC = . if (IRDPCOC >= 13 )
replace IRWSCIG = . if (IRWSCIG >= 13 )
replace IRWSALC = . if (IRWSALC >= 13 )
replace IRWSMJ = . if (IRWSMJ >= 13 )
replace IRWSCOC = . if (IRWSCOC >= 13 )
replace IRALCAGG = . if (IRALCAGG >= 91 )
replace IRALCARG = . if (IRALCARG >= 91 )
replace IRALCABS = . if (IRALCABS >= 91 )
replace IRALCHIG = . if (IRALCHIG >= 91 )
replace IRALCJOB = . if (IRALCJOB >= 91 )
replace IRALCMAT = . if (IRALCMAT >= 91 )
replace IRALCREL = . if (IRALCREL >= 91 )
replace IRALCFRD = . if (IRALCFRD >= 91 )
replace IRALCTOS = . if (IRALCTOS >= 91 )
replace IRALCHOL = . if (IRALCHOL >= 91 )
replace IRALCDRU = . if (IRALCDRU >= 91 )
replace IRALCINT = . if (IRALCINT >= 91 )
replace IRALCREM = . if (IRALCREM >= 91 )
replace IRALCQUI = . if (IRALCQUI >= 91 )
replace IRALCMOR = . if (IRALCMOR >= 91 )
replace IRALCSHO = . if (IRALCSHO >= 91 )
replace IRALCALO = . if (IRALCALO >= 91 )
replace IRALCBRK = . if (IRALCBRK >= 91 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

